@@ -145,6 +145,9 @@ LockStruct  LockProcs[] =
 	{"drift",
 	 10000, 30, 1, 1, 64, 1.0, "",
 	 "Shows cosmic drifting flame fractals", 0, NULL, NULL},
+    {"euler2d",
+     1000, 1024, 3000, 1, 64, 1.0, "",
+     "Shows a simulation of 2D incompressible inviscid fluid", 0, NULL, NULL},
 	{"eyes",
 	 20000, -8, 5, 1, 64, 1.0, "",
 	 "Shows eyes following a bouncing grelb", 0, NULL, NULL},
@@ -201,7 +204,7 @@ LockStruct  LockProcs[] =
 	 "Shows a sphere inverted without wrinkles", 0, NULL, "#if defined( USE_GL ) && defined( HAVE_CXX )"},
 #endif
         {"juggle",
-         2000, 30, 30, 1, 32, 1.0, "",
+         10000, 150, 30, 1, 64, 1.0, "",
          "Shows a Juggler, juggling", 0, NULL, NULL},
 	{"julia",
 	 10000, 1000, 20, 1, 64, 1.0, "",
@@ -313,6 +316,11 @@ LockStruct  LockProcs[] =
 	{"sierpinski",
 	 400000, 2000, 100, 1, 64, 1.0, "",
 	 "Shows Sierpinski's triangle", 0, NULL, NULL},
+#if defined(USE_GL) && defined( USE_UNSTABLE )
+	{"skewb",
+	 10000, -30, 5, 1, 64, 1.0, "",
+	 "Shows an auto-solving Skewb", 0, NULL, "#if defined(USE_GL) && defined( USE_UNSTABLE )"},
+#endif
 	{"slip",
 	 50000, 35, 50, 1, 64, 1.0, "",
 	 "Shows slipping blits", 0, NULL, NULL},
@@ -358,21 +366,21 @@ LockStruct  LockProcs[] =
 	 "Shows 3D mathematical shapes", 0, NULL, "#ifdef USE_GL"},
 #endif
 	{"swarm",
-	 15000, 100, 1, 1, 64, 1.0, "",
+	 15000, -100, 1, -100, 64, 1.0, "",
 	 "Shows a swarm of bees following a wasp", 0, NULL, NULL},
 	{"swirl",
 	 5000, 5, 1, 1, 64, 1.0, "",
 	 "Shows animated swirling patterns", 0, NULL, NULL},
-  {"t3d",
-   250000, 1000, 60000, 0, 64, 1.0, "",
-   "Shows a Flying Balls Clock Demo", 0, NULL, NULL},
+	{"t3d",
+	 250000, 1000, 60000, 0, 64, 1.0, "",
+	 "Shows a Flying Balls Clock Demo", 0, NULL, NULL},
 	{"tetris",
 	 50000, 1, 1, 0, 64, 1.0, "",
 	 "Shows an autoplaying tetris game", 0, NULL, NULL},
-#if defined(USE_GL) & defined(HAVE_CXX) && defined( HAVE_TTF ) && defined( HAVE_GLTT ) && defined( USE_UNSTABLE )
+#if defined(USE_GL) && defined(HAVE_CXX) && defined( HAVE_TTF ) && defined( HAVE_GLTT ) && defined( USE_UNSTABLE )
 	{"text3d",
 	 100000, 1, 1, 1, 64, 1.0, "",
-	 "Shows 3D text", 0, NULL, "#if defined(USE_GL) & defined(HAVE_CXX) && defined( HAVE_TTF ) && defined( HAVE_GLTT ) && defined( USE_UNSTABLE )"},
+	 "Shows 3D text", 0, NULL, "#if defined(USE_GL) && defined(HAVE_CXX) && defined( HAVE_TTF ) && defined( HAVE_GLTT ) && defined( USE_UNSTABLE )"},
 #endif
 	{"thornbird",
 	 1000, 800, 16, 1, 64, 1.0, "",
@@ -407,6 +415,9 @@ LockStruct  LockProcs[] =
 	{"worm",
 	 17000, -20, 10, -3, 64, 1.0, "",
 	 "Shows wiggly worms", 0, NULL, NULL},
+	{"xcl",
+	 20000, -3, 1, 1, 64, 1.0, "",
+	 "Shows a control line combat model race", 0, NULL, NULL},
 	{"xjack",
 	 50000, 1, 1, 1, 64, 1.0, "",
 	 "Shows Jack having one of those days", 0, NULL, NULL},
