@@ -671,6 +671,7 @@ demon\
 dilemma\
 discrete\
 drift\
+euler2d\
 eyes\
 fadeplot\
 flag\
@@ -723,6 +724,7 @@ rotor\
 rubik\
 shape\
 sierpinski\
+skewb\
 slip\
 solitare\
 space\
@@ -750,6 +752,7 @@ wator\
 wire\
 world\
 worm\
+xcl\
 xjack\
 blank\
 bomb\
