@@ -96,6 +96,7 @@ lst.addItem("demon");
 lst.addItem("dilemma");
 lst.addItem("discrete");
 lst.addItem("drift");
+lst.addItem("euler2d");
 lst.addItem("eyes");
 lst.addItem("fadeplot");
 lst.addItem("flag");
@@ -148,6 +149,7 @@ lst.addItem("rotor");
 lst.addItem("rubik");
 lst.addItem("shape");
 lst.addItem("sierpinski");
+lst.addItem("skewb");
 lst.addItem("slip");
 lst.addItem("solitare");
 lst.addItem("space");
@@ -175,6 +177,7 @@ lst.addItem("wator");
 lst.addItem("wire");
 lst.addItem("world");
 lst.addItem("worm");
+lst.addItem("xcl");
 lst.addItem("xjack");
 lst.addItem("blank");
 lst.addItem("bomb");
