@@ -90,27 +90,27 @@ static Bool sharpturn;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-neighbors", ".ant.neighbors", XrmoptionSepArg, (caddr_t) NULL},
-	{"-truchet", ".ant.truchet", XrmoptionNoArg, (caddr_t) "on"},
-	{"+truchet", ".ant.truchet", XrmoptionNoArg, (caddr_t) "off"},
-	{"-eyes", ".ant.eyes", XrmoptionNoArg, (caddr_t) "on"},
-	{"+eyes", ".ant.eyes", XrmoptionNoArg, (caddr_t) "off"},
-	{"-sharpturn", ".ant.sharpturn", XrmoptionNoArg, (caddr_t) "on"},
-	{"+sharpturn", ".ant.sharpturn", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-neighbors", (char *) ".ant.neighbors", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-truchet", (char *) ".ant.truchet", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+truchet", (char *) ".ant.truchet", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-eyes", (char *) ".ant.eyes", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+eyes", (char *) ".ant.eyes", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-sharpturn", (char *) ".ant.sharpturn", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+sharpturn", (char *) ".ant.sharpturn", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & neighbors, "neighbors", "Neighbors", DEF_NEIGHBORS, t_Int},
-	{(caddr_t *) & truchet, "truchet", "Truchet", DEF_TRUCHET, t_Bool},
-	{(caddr_t *) & eyes, "eyes", "Eyes", DEF_EYES, t_Bool},
-   {(caddr_t *) & sharpturn, "sharpturn", "SharpTurn", DEF_SHARPTURN, t_Bool}
+	{(caddr_t *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int},
+	{(caddr_t *) & truchet, (char *) "truchet", (char *) "Truchet", (char *) DEF_TRUCHET, t_Bool},
+	{(caddr_t *) & eyes, (char *) "eyes", (char *) "Eyes", (char *) DEF_EYES, t_Bool},
+   {(caddr_t *) & sharpturn, (char *) "sharpturn", (char *) "SharpTurn", (char *) DEF_SHARPTURN, t_Bool}
 };
 static OptionStruct desc[] =
 {
-	{"-neighbors num", "squares 4 or 8, hexagons 6, triangles 3 or 12"},
-	{"-/+truchet", "turn on/off Truchet lines"},
-	{"-/+eyes", "turn on/off eyes"},
-	{"-/+sharpturn", "turn on/off sharp turns (6, 8 or 12 neighbors only)"}
+	{(char *) "-neighbors num", (char *) "squares 4 or 8, hexagons 6, triangles 3 or 12"},
+	{(char *) "-/+truchet", (char *) "turn on/off Truchet lines"},
+	{(char *) "-/+eyes", (char *) "turn on/off eyes"},
+	{(char *) "-/+sharpturn", (char *) "turn on/off sharp turns (6, 8 or 12 neighbors only)"}
 };
 
 ModeSpecOpt ant_opts =
