@@ -150,6 +150,7 @@ typedef struct {
 	int         graphics_format;
 	int         pixelmode;
 	GC          backGC;
+	Pixmap      pixmap;
 	Colormap    cmap;
 	unsigned long black;
 	batstruct  *bats;
@@ -158,12 +159,6 @@ typedef struct {
 
 static bouncestruct *bounces = NULL;
 
-static void checkCollision(bouncestruct * bp, int a_bat);
-static void drawabat(ModeInfo * mi, batstruct * bat);
-static void movebat(bouncestruct * bp, batstruct * bat);
-static void flapbat(batstruct * bat, int dir, int *vel, int avgsize);
-static int  collide(bouncestruct * bp, int a_bat);
-
 static unsigned char *bits[] =
 {
 	bat0_bits, bat1_bits, bat2_bits, bat3_bits, bat4_bits
@@ -226,7 +221,7 @@ checkCollision(bouncestruct * bp, int a_bat)
 }
 
 static void
-drawabat(ModeInfo * mi, batstruct * bat)
+drawbat(ModeInfo * mi, batstruct * bat)
 {
 	Display    *display = MI_DISPLAY(mi);
 	Window      window = MI_WINDOW(mi);
@@ -239,8 +234,8 @@ drawabat(ModeInfo * mi, batstruct * bat)
 				     bat->xlast, bat->ylast, bp->xs, bp->ys);
 		}
 		XSetForeground(display, bp->backGC, bat->color);
-		XFillRectangle(display, window, bp->backGC,
-			       bat->x, bat->y, bp->xs, bp->ys);
+		XCopyPlane(display, bp->pixmap, window, bp->backGC,
+			0, 0, bp->xs, bp->ys, bat->x, bat->y, 1L);
 	} else {
 		XSetForeground(display, bp->backGC, bat->color);
 /* PURIFY 4.0.1 on SunOS4 and on Solaris 2 reports a 15985 byte memory leak on
@@ -257,6 +252,19 @@ drawabat(ModeInfo * mi, batstruct * bat)
 	}
 }
 
+static void
+flapbat(batstruct * bat, int dir, int *vel, int avgsize)
+{
+	*vel -= (int) ((*vel + SIGN(*vel * dir) *
+		 bat->spindelay * ORIENTCYCLE / (M_PI * avgsize)) / SLIPAGE);
+	if (*vel) {
+		bat->spindir = DIR(*vel * dir);
+		bat->vang = *vel * ORIENTCYCLE;
+		bat->spindelay = (int) ((double) M_PI * avgsize / (ABS(bat->vang))) + 1;
+	} else
+		bat->spindir = 0;
+}
+
 static void
 movebat(bouncestruct * bp, batstruct * bat)
 {
@@ -296,19 +304,6 @@ movebat(bouncestruct * bp, batstruct * bat)
 	}
 }
 
-static void
-flapbat(batstruct * bat, int dir, int *vel, int avgsize)
-{
-	*vel -= (int) ((*vel + SIGN(*vel * dir) *
-		 bat->spindelay * ORIENTCYCLE / (M_PI * avgsize)) / SLIPAGE);
-	if (*vel) {
-		bat->spindir = DIR(*vel * dir);
-		bat->vang = *vel * ORIENTCYCLE;
-		bat->spindelay = (int) ((double) M_PI * avgsize / (ABS(bat->vang))) + 1;
-	} else
-		bat->spindir = 0;
-}
-
 static int
 collide(bouncestruct * bp, int a_bat)
 {
@@ -441,6 +436,8 @@ free_stuff(Display * display, bouncestruct * bp)
 void
 init_bat(ModeInfo * mi)
 {
+	Display    *display = MI_DISPLAY(mi);
+	Window      window = MI_WINDOW(mi);
 	bouncestruct *bp;
 	int         size = MI_SIZE(mi);
 	int         i, tryagain = 0;
@@ -453,7 +450,7 @@ init_bat(ModeInfo * mi)
 	bp = &bounces[MI_SCREEN(mi)];
 
 #if defined( USE_XPM ) || defined( USE_XPMINC )
-	free_stuff(MI_DISPLAY(mi), bp);
+	free_stuff(display, bp);
 #endif
 
 	bp->width = MI_WIDTH(mi);
@@ -502,7 +499,45 @@ init_bat(ModeInfo * mi)
 	}
 	bp->avgsize = (bp->xs + bp->ys) / 2;
 
-	init_stuff(mi);
+    if (bp->pixelmode) {
+		GC fg_gc, bg_gc;
+		XGCValues gcv;
+
+		bp->pixmap = XCreatePixmap(display, window,
+		    bp->xs, bp->ys, 1);
+		gcv.foreground = 0;
+		gcv.background = 1;
+		bg_gc = XCreateGC(display, bp->pixmap,
+	         GCForeground | GCBackground, &gcv);
+		gcv.background = 0;
+		gcv.foreground = 1;
+		fg_gc = XCreateGC(display, bp->pixmap,
+	        GCForeground | GCBackground, &gcv);
+		XFillRectangle(display, bp->pixmap, bg_gc,
+	   		0, 0, bp->xs, bp->ys);
+		XFillArc(display, bp->pixmap, fg_gc,
+			0, 0, bp->xs / 2, 2 * bp->ys,
+			0, 11520);
+		XFillArc(display, bp->pixmap, fg_gc,
+			bp->xs / 2, 0, bp->xs / 2, 2 * bp->ys,
+			0, 11520);
+		XFillRectangle(display, bp->pixmap, fg_gc,
+			bp->xs / 4, bp->ys / 2,
+	        bp->xs / 2, bp->ys / 2);
+		XFillArc(display, bp->pixmap, bg_gc,
+			0, bp->ys / 2, bp->xs / 2, 2 * bp->ys,
+			0, 11520);
+		XFillArc(display, bp->pixmap, bg_gc,
+			bp->xs / 2, bp->ys / 2, bp->xs / 2, 2 * bp->ys,
+			0, 11520);
+		XFreeGC(display, bg_gc);
+		XFreeGC(display, fg_gc);
+
+		bp->black = MI_BLACK_PIXEL(mi);
+		bp->backGC = MI_GC(mi);
+	} else {
+		init_stuff(mi);
+	}
 
 	i = 0;
 	while (i < bp->nbats) {
@@ -526,6 +561,8 @@ init_bat(ModeInfo * mi)
 		} else
 			tryagain++;
 	}
+	/* don't want any exposure events from XCopyPlane */
+    XSetGraphicsExposures(display, MI_GC(mi), False);
 	MI_CLEARWINDOWCOLORMAP(mi, bp->backGC, bp->black);
 }
 
@@ -533,12 +570,12 @@ void
 draw_bat(ModeInfo * mi)
 {
 	bouncestruct *bp = &bounces[MI_SCREEN(mi)];
-	int         i;
+	int           i;
 
 	MI_IS_DRAWN(mi) = True;
 
 	for (i = 0; i < bp->nbats; i++) {
-		drawabat(mi, &bp->bats[i]);
+		drawbat(mi, &bp->bats[i]);
 		movebat(bp, &bp->bats[i]);
 	}
 	for (i = 0; i < bp->nbats; i++)
@@ -553,7 +590,7 @@ void
 release_bat(ModeInfo * mi)
 {
 	if (bounces != NULL) {
-		int         screen;
+		int        screen;
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++) {
 			bouncestruct *bp = &bounces[screen];
@@ -577,7 +614,7 @@ refresh_bat(ModeInfo * mi)
 
 	MI_CLEARWINDOWCOLORMAP(mi, bp->backGC, bp->black);
 #if defined( USE_XPM ) || defined( USE_XPMINC )
-	/* This is needed when another program changes the colormap. */ 
+	/* This is needed when another program changes the colormap. */
 	free_stuff(MI_DISPLAY(mi), bp);
 	init_stuff(mi);
 #endif
