@@ -214,41 +214,32 @@ drawball(ModeInfo * mi, ballstruct * ball)
 	Window      window = MI_WINDOW(mi);
 	bouncestruct *bp = &bounces[MI_SCREEN(mi)];
 
-	if (bp->pixelmode) {
-		if (ball->xlast != -1) {
-			XSetForeground(display, MI_GC(mi), MI_BLACK_PIXEL(mi));
-			XFillRectangle(display, window, MI_GC(mi),
-				   ball->xlast, ball->ylast, bp->xs, bp->ys);
-		}
-		XSetForeground(display, MI_GC(mi), ball->color);
-		XFillRectangle(display, window, MI_GC(mi),
-			       ball->x, ball->y, bp->xs, bp->ys);
-	} else {
-		if (ball->xlast != -1) {
-			XSetForeground(display, bp->stippledGC, MI_BLACK_PIXEL(mi));
-			XSetStipple(display, bp->stippledGC, bp->pixmaps[ORIENTS]);
-			XSetFillStyle(display, bp->stippledGC, FillStippled);
-			XSetTSOrigin(display, bp->stippledGC, ball->xlast, ball->ylast);
-#ifdef FLASH
-			XFillRectangle(display, window, bp->stippledGC,
-				   ball->xlast, ball->ylast, bp->xs, bp->ys);
-#else
-			ERASE_IMAGE(display, window, bp->stippledGC, ball->x, ball->y,
-				    ball->xlast, ball->ylast, bp->xs, bp->ys);
-#endif
-		}
-		XSetTSOrigin(display, bp->stippledGC, ball->x, ball->y);
-		XSetForeground(display, bp->stippledGC, ball->color);
-		XSetStipple(display, bp->stippledGC, bp->pixmaps[ball->orient]);
-#ifdef FLASH
+	if (ball->xlast != -1) {
+		XSetForeground(display, bp->stippledGC, MI_BLACK_PIXEL(mi));
+		XSetStipple(display, bp->stippledGC,
+			bp->pixmaps[(bp->pixelmode) ? 0 : ORIENTS]);
 		XSetFillStyle(display, bp->stippledGC, FillStippled);
-#else
-		XSetFillStyle(display, bp->stippledGC, FillOpaqueStippled);
-#endif
+		XSetTSOrigin(display, bp->stippledGC, ball->xlast, ball->ylast);
+#ifdef FLASH
 		XFillRectangle(display, window, bp->stippledGC,
-			       ball->x, ball->y, bp->xs, bp->ys);
-		XFlush(display);
+			ball->xlast, ball->ylast, bp->xs, bp->ys);
+#else
+		ERASE_IMAGE(display, window, bp->stippledGC, ball->x, ball->y,
+			ball->xlast, ball->ylast, bp->xs, bp->ys);
+#endif
 	}
+	XSetTSOrigin(display, bp->stippledGC, ball->x, ball->y);
+	XSetForeground(display, bp->stippledGC, ball->color);
+	XSetStipple(display, bp->stippledGC,
+		bp->pixmaps[(bp->pixelmode) ? 0 : ball->orient]);
+#ifdef FLASH
+	XSetFillStyle(display, bp->stippledGC, FillStippled);
+#else
+	XSetFillStyle(display, bp->stippledGC, FillOpaqueStippled);
+#endif
+	XFillRectangle(display, window, bp->stippledGC,
+		ball->x, ball->y, bp->xs, bp->ys);
+	XFlush(display);
 }
 
 static void
@@ -441,6 +432,20 @@ bounce_windows(ModeInfo * mi, bouncestruct * bs)
 	return;
 }
 
+static void
+freePixmaps(ModeInfo * mi)
+{
+	bouncestruct *bp = &bounces[MI_SCREEN(mi)];
+	Display    *display = MI_DISPLAY(mi);
+	int bits;
+
+	for (bits = 0; bits < bp->init_orients; bits++) {
+		XFreePixmap(display, bp->pixmaps[bits]);
+		bp->pixmaps[bits] = None;
+	}
+	bp->init_orients = 0;
+}
+
 void
 init_bounce(ModeInfo * mi)
 {
@@ -458,20 +463,6 @@ init_bounce(ModeInfo * mi)
 	}
 	bp = &bounces[MI_SCREEN(mi)];
 
-	if (!bp->stippledGC) {
-		gcv.foreground = MI_BLACK_PIXEL(mi);
-		gcv.background = MI_BLACK_PIXEL(mi);
-		if ((bp->stippledGC = XCreateGC(display, window,
-				 GCForeground | GCBackground, &gcv)) == None)
-			return;
-	}
-	if (!bp->init_orients) {
-		BALLBITS(bounce0_bits, bounce0_width, bounce0_height);
-		BALLBITS(bounce1_bits, bounce1_width, bounce1_height);
-		BALLBITS(bounce2_bits, bounce2_width, bounce2_height);
-		BALLBITS(bounce3_bits, bounce3_width, bounce3_height);
-		BALLBITS(bouncemask_bits, bouncemask_width, bouncemask_height);
-	}
 	bp->width = MI_WIDTH(mi);
 	bp->height = MI_HEIGHT(mi);
 	if (bp->width < 2)
@@ -516,6 +507,41 @@ init_bounce(ModeInfo * mi)
 					       MINGRIDSIZE));
 		bp->xs = bp->ys;
 	}
+	freePixmaps(mi);
+	if (!bp->stippledGC) {
+		gcv.foreground = MI_BLACK_PIXEL(mi);
+		gcv.background = MI_BLACK_PIXEL(mi);
+		if ((bp->stippledGC = XCreateGC(display, window,
+			 GCForeground | GCBackground, &gcv)) == None)
+			return;
+	}
+	if (bp->pixelmode) {
+		GC fg_gc, bg_gc;
+
+  		bp->pixmaps[0] = XCreatePixmap(display, window,
+			bp->xs, bp->ys, 1);
+		bp->init_orients = 1;
+		gcv.foreground = 0;
+		gcv.background = 1;
+		bg_gc = XCreateGC(display, bp->pixmaps[0],
+				 GCForeground | GCBackground, &gcv);
+		gcv.foreground = 1;
+		gcv.background = 0;
+		fg_gc = XCreateGC(display, bp->pixmaps[0],
+				 GCForeground | GCBackground, &gcv);
+		XFillRectangle(display, bp->pixmaps[0], bg_gc,
+			0, 0, bp->xs, bp->ys);
+		XFillArc(display, bp->pixmaps[0], fg_gc,
+			0, 0, bp->xs, bp->ys, 0, 23040);
+		XFreeGC(display, bg_gc);
+		XFreeGC(display, fg_gc);
+	} else {
+		BALLBITS(bounce0_bits, bounce0_width, bounce0_height);
+		BALLBITS(bounce1_bits, bounce1_width, bounce1_height);
+		BALLBITS(bounce2_bits, bounce2_width, bounce2_height);
+		BALLBITS(bounce3_bits, bounce3_width, bounce3_height);
+		BALLBITS(bouncemask_bits, bouncemask_width, bouncemask_height);
+	}
 	bp->avgsize = (bp->xs + bp->ys) / 2;
 	i = 0;
 	while (i < bp->nballs) {
@@ -572,14 +598,13 @@ release_bounce(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++) {
 			bouncestruct *bp = &bounces[screen];
-			int         bits;
 
 			if (bp->balls != NULL)
 				(void) free((void *) bp->balls);
-			if (bp->stippledGC != NULL)
+			if (bp->stippledGC != NULL) {
 				XFreeGC(MI_DISPLAY(mi), bp->stippledGC);
-			for (bits = 0; bits < bp->init_orients; bits++)
-				XFreePixmap(MI_DISPLAY(mi), bp->pixmaps[bits]);
+			}
+			freePixmaps(mi);
 		}
 		(void) free((void *) bounces);
 		bounces = NULL;
