@@ -61,19 +61,19 @@ static Bool eyes;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-neighbors", ".bug.neighbors", XrmoptionSepArg, (caddr_t) NULL},
-	{"-eyes", ".bug.eyes", XrmoptionNoArg, (caddr_t) "on"},
-	{"+eyes", ".bug.eyes", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-neighbors", (char *) ".bug.neighbors", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-eyes", (char *) ".bug.eyes", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+eyes", (char *) ".bug.eyes", XrmoptionNoArg, (caddr_t) "off"},
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & neighbors, "neighbors", "Neighbors", DEF_NEIGHBORS, t_Int},
-	{(caddr_t *) & eyes, "eyes", "Eyes", DEF_EYES, t_Bool},
+	{(caddr_t *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int},
+	{(caddr_t *) & eyes, (char *) "eyes", (char *) "Eyes", (char *) DEF_EYES, t_Bool},
 };
 static OptionStruct desc[] =
 {
-	{"-neighbors num", "squares 4 or 8, hexagons 6"},
-	{"-/+eyes", "turn on/off eyes"}
+	{(char *) "-neighbors num", (char *) "squares 4 or 8, hexagons 6"},
+	{(char *) "-/+eyes", (char *) "turn on/off eyes"}
 };
 
 ModeSpecOpt bug_opts =
