@@ -107,39 +107,39 @@ static Bool unit_cell, grid_cell, centre, maxsize, cycle_p;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-nx", "crystal.nx", XrmoptionSepArg, (caddr_t) NULL},
-	{"-ny", "crystal.ny", XrmoptionSepArg, (caddr_t) NULL},
-	{"-centre", ".crystal.centre", XrmoptionNoArg, (caddr_t) "on"},
-	{"+centre", ".crystal.centre", XrmoptionNoArg, (caddr_t) "off"},
-	{"-maxsize", ".crystal.maxsize", XrmoptionNoArg, (caddr_t) "on"},
-	{"+maxsize", ".crystal.maxsize", XrmoptionNoArg, (caddr_t) "off"},
-	{"-cell", ".crystal.cell", XrmoptionNoArg, (caddr_t) "on"},
-	{"+cell", ".crystal.cell", XrmoptionNoArg, (caddr_t) "off"},
-	{"-grid", ".crystal.grid", XrmoptionNoArg, (caddr_t) "on"},
-	{"+grid", ".crystal.grid", XrmoptionNoArg, (caddr_t) "off"},
-	{"-cycle", ".crystal.cycle", XrmoptionNoArg, (caddr_t) "on"},
-	{"+cycle", ".crystal.cycle", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-nx", (char *) "crystal.nx", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-ny", (char *) "crystal.ny", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-centre", (char *) ".crystal.centre", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+centre", (char *) ".crystal.centre", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-maxsize", (char *) ".crystal.maxsize", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+maxsize", (char *) ".crystal.maxsize", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-cell", (char *) ".crystal.cell", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+cell", (char *) ".crystal.cell", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-grid", (char *) ".crystal.grid", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+grid", (char *) ".crystal.grid", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-cycle", (char *) ".crystal.cycle", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+cycle", (char *) ".crystal.cycle", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & nx, "nx", "nx", DEF_NX, t_Int},
-	{(caddr_t *) & ny, "ny", "ny", DEF_NY, t_Int},
-	{(caddr_t *) & centre, "centre", "Centre", DEF_CENTRE, t_Bool},
-	{(caddr_t *) & maxsize, "maxsize", "Maxsize", DEF_MAXSIZE, t_Bool},
-	{(caddr_t *) & unit_cell, "cell", "Cell", DEF_CELL, t_Bool},
-	{(caddr_t *) & grid_cell, "grid", "Grid", DEF_GRID, t_Bool},
-	{(caddr_t *) & cycle_p, "cycle", "Cycle", DEF_CYCLE, t_Bool}
+	{(caddr_t *) & nx, (char *) "nx", (char *) "nx", (char *) DEF_NX, t_Int},
+	{(caddr_t *) & ny, (char *) "ny", (char *) "ny", (char *) DEF_NY, t_Int},
+	{(caddr_t *) & centre, (char *) "centre", (char *) "Centre", (char *) DEF_CENTRE, t_Bool},
+	{(caddr_t *) & maxsize, (char *) "maxsize", (char *) "Maxsize", (char *) DEF_MAXSIZE, t_Bool},
+	{(caddr_t *) & unit_cell, (char *) "cell", (char *) "Cell", (char *) DEF_CELL, t_Bool},
+	{(caddr_t *) & grid_cell, (char *) "grid", (char *) "Grid", (char *) DEF_GRID, t_Bool},
+	{(caddr_t *) & cycle_p, (char *) "cycle", (char *) "Cycle", (char *) DEF_CYCLE, t_Bool}
 };
 static OptionStruct desc[] =
 {
-	{"-nx num", "Number of unit cells in x-direction"},
-	{"-ny num", "Number of unit cells in y-direction"},
-	{"-/+centre", "turn on/off centering on screen"},
-	{"-/+maxsize", "turn on/off use of maximum part of screen"},
-	{"-/+cell", "turn on/off drawing of unit cell"},
-   {"-/+grid", "turn on/off drawing of grid of unit cells (if -cell is on)"},
-	{"-/+cycle", "turn on/off colour cycling"}
+	{(char *) "-nx num", (char *) "Number of unit cells in x-direction"},
+	{(char *) "-ny num", (char *) "Number of unit cells in y-direction"},
+	{(char *) "-/+centre", (char *) "turn on/off centering on screen"},
+	{(char *) "-/+maxsize", (char *) "turn on/off use of maximum part of screen"},
+	{(char *) "-/+cell", (char *) "turn on/off drawing of unit cell"},
+	{(char *) "-/+grid", (char *) "turn on/off drawing of grid of unit cells (if -cell is on)"},
+	{(char *) "-/+cycle", (char *) "turn on/off colour cycling"}
 };
 
 ModeSpecOpt crystal_opts =
@@ -1268,7 +1268,7 @@ init_crystal(ModeInfo * mi)
 		crystal_setupatom(atom0, cryst->gamma);
 		crystal_drawatom(mi, atom0);
 	}
-	XSync(display, False);
+	XFlush(display);
 	XSetFunction(display, cryst->gc, GXcopy);
 }
 
