@@ -205,7 +205,7 @@ init_decay (ModeInfo * mi)
 	else {
 		if (s && *s && !!strcmp(s, "random"))
 			(void) fprintf(stderr, "%s: unknown mode %s\n", ProgramName, s);
-		dp->mode = LRAND() % (OUT+1);
+		dp->mode = (int) (LRAND() % (OUT+1));
 	}
 
 	if (MI_IS_FULLRANDOM(mi) && !hide)
