@@ -39,7 +39,7 @@ static const char sccsid[] = "@(#)demon.c	4.07 97/11/24 xlockmore";
  */
 
 /*-
-  Grid     Number of Neigbors
+  Grid     Number of Neighbors
   ----     ------------------
   Square   4 or 8
   Hexagon  6
@@ -76,16 +76,16 @@ static int  neighbors;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-neighbors", ".demon.neighbors", XrmoptionSepArg, (caddr_t) NULL}
+	{(char *) "-neighbors", (char *) ".demon.neighbors", XrmoptionSepArg, (caddr_t) NULL}
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & neighbors, "neighbors", "Neighbors", DEF_NEIGHBORS, t_Int}
+	{(caddr_t *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int}
 };
 static OptionStruct desc[] =
 {
-	{"-neighbors num", "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"}
+	{(char *) "-neighbors num", (char *) "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"}
 };
 
 ModeSpecOpt demon_opts =
