@@ -35,6 +35,10 @@ static const char sccsid[] = "@(#)eyes.c	4.07 97/11/24 xlockmore";
  *            Allow the Grelb to enter from either side.
  * 18-Feb-96: Got the code into mostly working condition.
  * 15-Feb-96: Had a brainwave, started hacking the xeyes code.
+ *
+ * Put "random rotations and horizontal shifts in.
+ * At first try make the shifts "random" with a weighting scheme favouring
+ * shifts towards the most empty region.
  */
 
 #ifdef STANDALONE
@@ -64,18 +68,18 @@ static Bool trackmouse;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-track", ".eyes.trackmouse", XrmoptionNoArg, (caddr_t) "on"},
-	{"+track", ".eyes.trackmouse", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-trackmouse", (char *) ".eyes.trackmouse", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+trackmouse", (char *) ".eyes.trackmouse", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & trackmouse, "trackmouse", "TrackMouse", DEF_TRACKMOUSE, t_Bool}
+	{(caddr_t *) & trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool}
 };
 
 static OptionStruct desc[] =
 {
-	{"-/+trackmouse", "turn on/off the tracking of the mouse"}
+	{(char *) "-/+trackmouse", (char *) "turn on/off the tracking of the mouse"}
 };
 
 ModeSpecOpt eyes_opts =
@@ -598,8 +602,9 @@ move_fly(ModeInfo * mi, Fly * f)
 				     &r, &c, &rx, &ry, &cx, &cy, &m);
 		if (cx <= 0 || cy <= 0 ||
 		    cx >= MI_WIDTH(mi) - f->width - 1 ||
-		    cy >= MI_HEIGHT(mi) - f->width - 1)
+		    cy >= MI_HEIGHT(mi) - f->width - 1) {
 			track_p = False;
+		}
 	}
 	if (track_p) {
 		f->x = cx;
