@@ -93,16 +93,16 @@ static Bool invert;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-invert", ".flag.invert", XrmoptionNoArg, (caddr_t) "on"},
-	{"+invert", ".flag.invert", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-invert", (char *) ".flag.invert", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+invert", (char *) ".flag.invert", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & invert, "invert", "Invert", DEF_INVERT, t_Bool}
+	{(caddr_t *) & invert, (char *) "invert", (char *) "Invert", (char *) DEF_INVERT, t_Bool}
 };
 static OptionStruct desc[] =
 {
-	{"-/+invert", "turn on/off inverting of flag"}
+	{(char *) "-/+invert", (char *) "turn on/off inverting of flag"}
 };
 
 ModeSpecOpt flag_opts =
