@@ -7,7 +7,7 @@ static const char sccsid[] = "@(#)flow.c 4.13 99/02/04 xlockmore";
 #endif
 
 /*-
- * Copyright (c) 1996 by Tim Auckland <Tim.Auckland@Sun.COM>
+ * Copyright (c) 1996 by Tim Auckland <Tim.Auckland@Procket.com>
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation for any purpose and without fee is hereby granted,
@@ -22,7 +22,7 @@ static const char sccsid[] = "@(#)flow.c 4.13 99/02/04 xlockmore";
  * other special, indirect and consequential damages.
  *
  * "flow" shows a variety of continuous phase-space flows around strange
- * attractors.  It includes the well-known Lorentz mask (the "Butterfly"
+ * attractors.  It includes the well-known Lorenz mask (the "Butterfly"
  * of chaos fame), two forms of Rossler's "Folded Band" and Poincare'
  * sections of the "Birkhoff Bagel" and Duffing's forced occilator.
  *
@@ -130,7 +130,7 @@ typedef struct {
 static flowstruct *flows = NULL;
 
 static dvector
-Lorentz(Par par, double x, double y, double z)
+Lorenz(Par par, double x, double y, double z)
 {
 	dvector d;
 
@@ -219,7 +219,7 @@ init_flow(ModeInfo * mi)
 		beemult = 3;
 		/* fallthrough */
 	case 1:
-		sp->ODE = Lorentz;
+		sp->ODE = Lorenz;
 		sp->step = 0.02;
 		sp->size = 60;
 		sp->centre.x = 0;
