@@ -29,9 +29,9 @@ static const char sccsid[] = "@(#)galaxy.c	4.07 97/11/24 xlockmore";
  * 10-May-97: Compatible with xscreensaver
  * 18-Apr-97: Memory leak fixed by Tom Schmidt <tschmidt@micron.com>
  * 07-Apr-97: Modified by Dave Mitchell <davem@magnet.com>
- * 23-Oct-94: Modified by David Bagley <bagleyd@tux.org>
  *            random star sizes
  *            colors change depending on velocity
+ * 23-Oct-94: Modified by David Bagley <bagleyd@tux.org>
  * 10-Oct-94: Add colors by Hubert Feyer
  * 30-Sep-94: Initial port by Hubert Feyer
  * 09-Mar-94: VMS can generate a random number 0.0 which results in a
@@ -64,18 +64,18 @@ static Bool tracks;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-tracks", ".galaxy.tracks", XrmoptionNoArg, (caddr_t) "on"},
-	{"+tracks", ".galaxy.tracks", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-tracks", (char *) ".galaxy.tracks", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+tracks", (char *) ".galaxy.tracks", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & tracks, "tracks", "Tracks", DEF_TRACKS, t_Bool}
+	{(caddr_t *) & tracks, (char *) "tracks", (char *) "Tracks", (char *) DEF_TRACKS, t_Bool}
 };
 
 static OptionStruct desc[] =
 {
-	{"-/+tracks", "turn on/off star tracks"}
+	{(char *) "-/+tracks", (char *) "turn on/off star tracks"}
 };
 
 ModeSpecOpt galaxy_opts =
