@@ -124,17 +124,17 @@ static const char sccsid[] = "@(#)atlantis.c	1.4 2000/01/28 xlockmore";
 static int  whalespeed;
 static XrmOptionDescRec opts[] =
 {
-     {"-whalespeed", ".atlantis.whalespeed", XrmoptionSepArg, (caddr_t) NULL}
+     {(char *) "-whalespeed", (char *) ".atlantis.whalespeed", XrmoptionSepArg, (caddr_t) NULL}
 };
 
 static argtype vars[] =
 {
-{(caddr_t *) & whalespeed, "whalespeed", "WhaleSpeed", DEF_WHALESPEED, t_Int}
+{(caddr_t *) & whalespeed, (char *) "whalespeed", (char *) "WhaleSpeed", (char *) DEF_WHALESPEED, t_Int}
 };
 
 static OptionStruct desc[] =
 {
-	{"-whalespeed num", "speed of whales and the dolphin"}
+	{(char *) "-whalespeed num", (char *) "speed of whales and the dolphin"}
 };
 
 ModeSpecOpt atlantis_opts =
