@@ -440,12 +440,15 @@ void
 release_cage(ModeInfo * mi)
 {
 	if (cage != NULL) {
+		cagestruct *cp = &cage[MI_SCREEN(mi)];
+
+		if (cp->glx_context) {
+			if (glIsList(objects))
+				glDeleteLists(objects, 1);
+		}
 		(void) free((void *) cage);
 		cage = NULL;
 	}
-	if (glIsList(objects)) {
-		glDeleteLists(objects, 1);
-	}
 	FreeAllGL(mi);
 }
 
