@@ -55,7 +55,7 @@ static const char sccsid[] = "@(#)gears.c	4.07 97/11/24 xlockmore";
 #include "vis.h"
 #endif /* !STANDALONE */
 
-#ifdef USE_GL
+#ifdef MODE_cage
 
 ModeSpecOpt gears_opts =
 {0, NULL, 0, NULL, NULL};
@@ -449,6 +449,7 @@ init_gears(ModeInfo * mi)
 
 	if ((gp->glx_context = init_GL(mi)) != NULL) {
 		reshape(MI_WIDTH(mi), MI_HEIGHT(mi));
+	    glDrawBuffer(GL_BACK);
 		pinit(mi);
 	} else {
 		MI_CLEARWINDOW(mi);
@@ -469,8 +470,6 @@ draw_gears(ModeInfo * mi)
 	if (!gp->glx_context)
 		return;
 
-	glDrawBuffer(GL_BACK);
-
 	glXMakeCurrent(display, window, *(gp->glx_context));
 	draw(mi);
 
