@@ -113,18 +113,18 @@ static Bool do_texture;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-texture", ".lament.texture", XrmoptionNoArg, (caddr_t) "on"},
-	{"+texture", ".lament.texture", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-texture", (char *) ".lament.texture", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+texture", (char *) ".lament.texture", XrmoptionNoArg, (caddr_t) "off"},
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & do_texture, "texture", "Texture", DEF_TEXTURE, t_Bool},
+	{(caddr_t *) & do_texture, (char *) "texture", (char *) "Texture", (char *) DEF_TEXTURE, t_Bool},
 };
 
 static OptionStruct desc[] =
 {
-	{"-/+texture", "turn on/off texturing"}
+	{(char *) "-/+texture", (char *) "turn on/off texturing"}
 };
 
 ModeSpecOpt lament_opts =
