@@ -695,12 +695,15 @@ void
 release_moebius(ModeInfo * mi)
 {
 	if (moebius != NULL) {
+		moebiusstruct *mp = &moebius[MI_SCREEN(mi)];
+
+		if (mp->glx_context) {
+			if (glIsList(objects))
+				glDeleteLists(objects, 3);
+		}
 		(void) free((void *) moebius);
 		moebius = NULL;
 	}
-	if (glIsList(objects)) {
-		glDeleteLists(objects, 3);
-	}
 	FreeAllGL(mi);
 }
 
