@@ -86,27 +86,27 @@ static Bool fisheye, tightturns, rotatepipes;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-factory", ".pipes.factory", XrmoptionSepArg, (caddr_t) NULL},
-	{"-fisheye", ".pipes.fisheye", XrmoptionNoArg, (caddr_t) "on"},
-	{"+fisheye", ".pipes.fisheye", XrmoptionNoArg, (caddr_t) "off"},
-	{"-tightturns", ".pipes.tightturns", XrmoptionNoArg, (caddr_t) "on"},
-	{"+tightturns", ".pipes.tightturns", XrmoptionNoArg, (caddr_t) "off"},
-      {"-rotatepipes", ".pipes.rotatepipes", XrmoptionNoArg, (caddr_t) "on"},
-      {"+rotatepipes", ".pipes.rotatepipes", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-factory", (char *) ".pipes.factory", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-fisheye", (char *) ".pipes.fisheye", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+fisheye", (char *) ".pipes.fisheye", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-tightturns", (char *) ".pipes.tightturns", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+tightturns", (char *) ".pipes.tightturns", XrmoptionNoArg, (caddr_t) "off"},
+      {(char *) "-rotatepipes", (char *) ".pipes.rotatepipes", XrmoptionNoArg, (caddr_t) "on"},
+      {(char *) "+rotatepipes", (char *) ".pipes.rotatepipes", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & factory, "factory", "Factory", DEF_FACTORY, t_Int},
-	{(caddr_t *) & fisheye, "fisheye", "Fisheye", DEF_FISHEYE, t_Bool},
-	{(caddr_t *) & tightturns, "tightturns", "Tightturns", DEF_TIGHTTURNS, t_Bool},
-	{(caddr_t *) & rotatepipes, "rotatepipes", "Rotatepipes", DEF_ROTATEPIPES, t_Bool}
+	{(caddr_t *) & factory, (char *) "factory", (char *) "Factory", (char *) DEF_FACTORY, t_Int},
+	{(caddr_t *) & fisheye, (char *) "fisheye", (char *) "Fisheye", (char *) DEF_FISHEYE, t_Bool},
+	{(caddr_t *) & tightturns, (char *) "tightturns", (char *) "Tightturns", (char *) DEF_TIGHTTURNS, t_Bool},
+	{(caddr_t *) & rotatepipes, (char *) "rotatepipes", (char *) "Rotatepipes", (char *) DEF_ROTATEPIPES, t_Bool}
 };
 static OptionStruct desc[] =
 {
-	{"-factory num", "how much extra equipment in pipes (0 for none)"},
-	{"-/+fisheye", "turn on/off zoomed-in view of pipes"},
-	{"-/+tightturns", "turn on/off tight turns"},
-	{"-/+rotatepipes", "turn on/off pipe system rotation per screenful"}
+	{(char *) "-factory num", (char *) "how much extra equipment in pipes (0 for none)"},
+	{(char *) "-/+fisheye", (char *) "turn on/off zoomed-in view of pipes"},
+	{(char *) "-/+tightturns", (char *) "turn on/off tight turns"},
+	{(char *) "-/+rotatepipes", (char *) "turn on/off pipe system rotation per screenful"}
 };
 
 ModeSpecOpt pipes_opts =
