@@ -2040,13 +2040,15 @@ release_rubik(ModeInfo * mi)
 					(void) free((void *) rp->rowLoc[i]);
 			if (rp->moves != NULL)
 				(void) free((void *) rp->moves);
+			if (rp->glx_context) {
+				glXMakeCurrent(MI_DISPLAY(mi), MI_WINDOW(mi), *(rp->glx_context));
+				if (glIsList(objects))
+					glDeleteLists(objects, 1);
+			}
 		}
 		(void) free((void *) rubik);
 		rubik = NULL;
 	}
-	if (glIsList(objects)) {
-		glDeleteLists(objects, 1);
-	}
 	FreeAllGL(mi);
 }
 
