@@ -1572,12 +1572,14 @@ release_skewb(ModeInfo * mi)
 
 			if (sp->moves != NULL)
 				(void) free((void *) sp->moves);
+			if (sp->glx_context) {
+				glXMakeCurrent(MI_DISPLAY(mi), MI_WINDOW(mi), *(sp->glx_context));
+				if (glIsList(objects))
+			                glDeleteLists(objects, 2);
+			}
 		}
 		(void) free((void *) skewb);
 		skewb = NULL;
-	}
-	if (glIsList(objects)) {
-                glDeleteLists(objects, 2);
         }
 	FreeAllGL(mi);
 }
