@@ -72,7 +72,9 @@ extern "C"
 #else				/* !STANDALONE */
 #include "xlock.h"		/* from the xlockmore distribution */
 #include "vis.h"
-
+#ifdef HAS_MMOV
+#undef error
+#endif
 #endif				/* !STANDALONE */
 
 #ifdef MODE_text3d
@@ -126,33 +128,33 @@ static char *animate;
 
 static XrmOptionDescRec opts[] =
 {
-    {"-ttfont", ".text3d.ttfont", XrmoptionSepArg, (caddr_t) NULL},
-    {"-extrusion", ".text3d.extrusion", XrmoptionSepArg, (caddr_t) NULL},
-    {"-rot_amplitude", ".text3d.rot_amplitude", XrmoptionSepArg, (caddr_t) NULL},
-    {"-rot_frequency", ".text3d.rot_frequency", XrmoptionSepArg, (caddr_t) NULL},
-    {"-no_split", ".text3d.no_split", XrmoptionNoArg, (caddr_t) "on"},
-    {"+no_split", ".text3d.no_split", XrmoptionNoArg, (caddr_t) "off"},
-    {"-ttanimate", ".text3d.ttanimate", XrmoptionSepArg, (caddr_t) NULL},
+    {(char *) "-ttfont", (char *) ".text3d.ttfont", XrmoptionSepArg, (caddr_t) NULL},
+    {(char *) "-extrusion", (char *) ".text3d.extrusion", XrmoptionSepArg, (caddr_t) NULL},
+    {(char *) "-rot_amplitude", (char *) ".text3d.rot_amplitude", XrmoptionSepArg, (caddr_t) NULL},
+    {(char *) "-rot_frequency", (char *) ".text3d.rot_frequency", XrmoptionSepArg, (caddr_t) NULL},
+    {(char *) "-no_split", (char *) ".text3d.no_split", XrmoptionNoArg, (caddr_t) "on"},
+    {(char *) "+no_split", (char *) ".text3d.no_split", XrmoptionNoArg, (caddr_t) "off"},
+    {(char *) "-ttanimate", (char *) ".text3d.ttanimate", XrmoptionSepArg, (caddr_t) NULL},
 };
 
 static argtype vars[] =
 {
-    {(caddr_t *) & mode_font, "ttfont", "TTFont", DEF_FONT, t_String},
-    {(caddr_t *) & extrusion, "extrusion", "Extrusion", DEF_EXTRUSION, t_Float},
-    {(caddr_t *) & rampl, "rot_amplitude", "RotationAmplitude", DEF_ROTAMPL, t_Float},
-    {(caddr_t *) & rfreq, "rot_frequency", "RotationFrequency", DEF_ROTFREQ, t_Float},
-    {(caddr_t *) & nosplit, "no_split", "NoSplit", DEF_NOSPLIT, t_Bool},
-    {(caddr_t *) & animate, "ttanimate", "TTAnimate", DEF_ANIMATE, t_String},
+    {(caddr_t *) & mode_font, (char *) "ttfont", (char *) "TTFont", (char *) DEF_FONT, t_String},
+    {(caddr_t *) & extrusion, (char *) "extrusion", (char *) "Extrusion", (char *) DEF_EXTRUSION, t_Float},
+    {(caddr_t *) & rampl, (char *) "rot_amplitude", (char *) "RotationAmplitude", (char *) DEF_ROTAMPL, t_Float},
+    {(caddr_t *) & rfreq, (char *) "rot_frequency", (char *) "RotationFrequency", (char *) DEF_ROTFREQ, t_Float},
+    {(caddr_t *) & nosplit, (char *) "no_split", (char *) "NoSplit", (char *) DEF_NOSPLIT, t_Bool},
+    {(caddr_t *) & animate, (char *) "ttanimate", (char *) "TTAnimate", (char *) DEF_ANIMATE, t_String},
 };
 
 static OptionStruct desc[] =
 {
-    {"-ttfont filename", "Text3d TrueType font file name"},
-    {"-extrusion float", "Text3d extrusion length"},
-    {"-rot_amplitude float", "Text3d rotation amplitude"},
-    {"-rot_frequency float", "Text3d rotation frequency"},
-    {"-/+no_split", "Text3d words splitting off/on"},
-    {"-ttanimate anim_name", "Text3d animation function"},
+    {(char *) "-ttfont filename", (char *) "Text3d TrueType font file name"},
+    {(char *) "-extrusion float", (char *) "Text3d extrusion length"},
+    {(char *) "-rot_amplitude float", (char *) "Text3d rotation amplitude"},
+    {(char *) "-rot_frequency float", (char *) "Text3d rotation frequency"},
+    {(char *) "-/+no_split", (char *) "Text3d words splitting off/on"},
+    {(char *) "-ttanimate anim_name", (char *) "Text3d animation function"},
 };
 
 ModeSpecOpt text3d_opts =
