@@ -67,16 +67,16 @@ static Bool ellipse;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-ellipse", ".helix.ellipse", XrmoptionNoArg, (caddr_t) "on"},
-	{"+ellipse", ".helix.ellipse", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-ellipse", (char *) ".helix.ellipse", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+ellipse", (char *) ".helix.ellipse", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & ellipse, "ellipse", "Ellipse", DEF_ELLIPSE, t_Bool}
+	{(caddr_t *) & ellipse, (char *) "ellipse", (char *) "Ellipse", (char *) DEF_ELLIPSE, t_Bool}
 };
 static OptionStruct desc[] =
 {
-	{"-/+ellipse", "turn on/off ellipse format"}
+	{(char *) "-/+ellipse", (char *) "turn on/off ellipse format"}
 };
 
 ModeSpecOpt helix_opts =
