@@ -115,8 +115,8 @@ so the answer is to do a single 661 and then drop straight down to (5).
 #ifdef MODE_juggle
 
 #define DEF_PATTERN "" /* All patterns */
-#define DEF_PATTERNTRACE 0 /* No trace */
-#define DEF_SOLID 0 /* Not solid */
+#define DEF_PATTERNTRACE "0" /* No trace */
+#define DEF_SOLID "0" /* Not solid */
 
 static char *pattern;
 static int patterntrace;
@@ -145,7 +145,7 @@ static OptionStruct desc[] =
 {
   {(char *) "-pattern string", (char *) "Cambridge Juggling Pattern"},
   {(char *) "-patterntrace num", (char *) "Trace Juggling Patterns"},
-  {(char *) "-/+solid", (char *) "Trace Juggling Patterns"},
+  {(char *) "-/+solid", (char *) "solid color (else its a 4 panel look (half white))"},
 };
 
 ModeSpecOpt juggle_opts =
