@@ -67,18 +67,18 @@ static Bool trackmouse;
 
 static XrmOptionDescRec opts[] =
 {
-        {"-trackmouse", ".julia.trackmouse", XrmoptionNoArg, (caddr_t) "on"},
-        {"+trackmouse", ".julia.trackmouse", XrmoptionNoArg, (caddr_t) "off"}
+        {(char *) "-trackmouse", (char *) ".julia.trackmouse", XrmoptionNoArg, (caddr_t) "on"},
+        {(char *) "+trackmouse", (char *) ".julia.trackmouse", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
-        {(caddr_t *) & trackmouse, "trackmouse", "TrackMouse", DEF_TRACKMOUSE, t_Bool}
+        {(caddr_t *) & trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool}
 };
 
 static OptionStruct desc[] =
 {
-        {"-/+trackmouse", "turn on/off the tracking of the mouse"}
+        {(char *) "-/+trackmouse", (char *) "turn on/off the tracking of the mouse"}
 };
 
 ModeSpecOpt julia_opts =
