@@ -98,38 +98,38 @@ static Bool Linear;
 
 static XrmOptionDescRec opts[] =
 {
-   {"-disconnected", ".kaleid.disconnected", XrmoptionNoArg, (caddr_t) "on"},
-  {"+disconnected", ".kaleid.disconnected", XrmoptionNoArg, (caddr_t) "off"},
-	{"-serial", ".kaleid.serial", XrmoptionNoArg, (caddr_t) "on"},
-	{"+serial", ".kaleid.serial", XrmoptionNoArg, (caddr_t) "off"},
-	{"-alternate", ".kaleid.alternate", XrmoptionNoArg, (caddr_t) "on"},
-	{"+alternate", ".kaleid.alternate", XrmoptionNoArg, (caddr_t) "off"},
-	{"-quad", ".kaleid.quad", XrmoptionNoArg, (caddr_t) "on"},
-	{"+quad", ".kaleid.quad", XrmoptionNoArg, (caddr_t) "off"},
-	{"-oct", ".kaleid.oct", XrmoptionNoArg, (caddr_t) "on"},
-	{"+oct", ".kaleid.oct", XrmoptionNoArg, (caddr_t) "off"},
-	{"-linear", ".kaleid.linear", XrmoptionNoArg, (caddr_t) "on"},
-	{"+linear", ".kaleid.linear", XrmoptionNoArg, (caddr_t) "off"}
+   {(char *) "-disconnected", (char *) ".kaleid.disconnected", XrmoptionNoArg, (caddr_t) "on"},
+  {(char *) "+disconnected", (char *) ".kaleid.disconnected", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-serial", (char *) ".kaleid.serial", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+serial", (char *) ".kaleid.serial", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-alternate", (char *) ".kaleid.alternate", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+alternate", (char *) ".kaleid.alternate", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-quad", (char *) ".kaleid.quad", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+quad", (char *) ".kaleid.quad", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-oct", (char *) ".kaleid.oct", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+oct", (char *) ".kaleid.oct", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-linear", (char *) ".kaleid.linear", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+linear", (char *) ".kaleid.linear", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & Disconnected, "disconnected", "Disconnected", DEF_DISCONNECTED, t_Bool},
-	{(caddr_t *) & Serial, "serial", "Serial", DEF_SERIAL, t_Bool},
-  {(caddr_t *) & Alternate, "alternate", "Alternate", DEF_ALTERNATE, t_Bool},
-	{(caddr_t *) & Quad, "quad", "Quad", DEF_QUAD, t_Bool},
-	{(caddr_t *) & Oct, "oct", "Oct", DEF_OCT, t_Bool},
-	{(caddr_t *) & Linear, "linear", "Linear", DEF_LINEAR, t_Bool}
+	{(caddr_t *) & Disconnected, (char *) "disconnected", (char *) "Disconnected", (char *) DEF_DISCONNECTED, t_Bool},
+	{(caddr_t *) & Serial, (char *) "serial", (char *) "Serial", (char *) DEF_SERIAL, t_Bool},
+  {(caddr_t *) & Alternate, (char *) "alternate", (char *) "Alternate", (char *) DEF_ALTERNATE, t_Bool},
+	{(caddr_t *) & Quad, (char *) "quad", (char *) "Quad", (char *) DEF_QUAD, t_Bool},
+	{(caddr_t *) & Oct, (char *) "oct", (char *) "Oct", (char *) DEF_OCT, t_Bool},
+	{(caddr_t *) & Linear, (char *) "linear", (char *) "Linear", (char *) DEF_LINEAR, t_Bool}
 };
 
 static OptionStruct desc[] =
 {
-	{"-/+disconnected", "turn on/off disconnected pen movement"},
-	{"-/+serial", "turn on/off sequential color selection"},
-	{"-/+alternate", "turn on/off alternate display mode"},
-	{"-/+quad", "turn on/off quad mirrored display mode"},
-	{"-/+oct", "turn on/off oct mirrored display mode"},
-	{"-/+linear", "select Cartesian/Polar coordinate display mode"}
+	{(char *) "-/+disconnected", (char *) "turn on/off disconnected pen movement"},
+	{(char *) "-/+serial", (char *) "turn on/off sequential color selection"},
+	{(char *) "-/+alternate", (char *) "turn on/off alternate display mode"},
+	{(char *) "-/+quad", (char *) "turn on/off quad mirrored display mode"},
+	{(char *) "-/+oct", (char *) "turn on/off oct mirrored display mode"},
+	{(char *) "-/+linear", (char *) "select Cartesian/Polar coordinate display mode"}
 };
 
 ModeSpecOpt kaleid_opts =
