@@ -87,36 +87,36 @@ static float speed;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-speed", ".kumppa.speed", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-speed", (char *) ".kumppa.speed", XrmoptionSepArg, (caddr_t) NULL},
 #if 0
 #ifdef HAVE_XDBE_EXTENSION
-	{"-dbuf", ".kumppa.dbuf", XrmoptionNoArg, (caddr_t) "on"},
-	{"+dbuf", ".kumppa.dbuf", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-dbuf", (char *) ".kumppa.dbuf", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+dbuf", (char *) ".kumppa.dbuf", XrmoptionNoArg, (caddr_t) "off"},
 #endif				/* HAVE_XDBE_EXTENSION */
 #endif
-	{"-rrandom", ".kumppa.rrandom", XrmoptionNoArg, (caddr_t) "on"},
-	{"+rrandom", ".kumppa.rrandom", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-rrandom", (char *) ".kumppa.rrandom", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+rrandom", (char *) ".kumppa.rrandom", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & speed, "speed", "speed", DEF_SPEED, t_Float},
+	{(caddr_t *) & speed, (char *) "speed", (char *) "speed", (char *) DEF_SPEED, t_Float},
 #if 0
 #ifdef HAVE_XDBE_EXTENSION
-	{(caddr_t *) & usedouble, "dbuf", "dbuf", DEF_USEDOUBLE, t_Bool},
+	{(caddr_t *) & usedouble, (char *) "dbuf", (char *) "dbuf", (char *) DEF_USEDOUBLE, t_Bool},
 #endif				/* HAVE_XDBE_EXTENSION */
 #endif
-	{(caddr_t *) & cosilines, "rrandom", "rrandom", DEF_COSILINES, t_Bool}
+	{(caddr_t *) & cosilines, (char *) "rrandom", (char *) "rrandom", (char *) DEF_COSILINES, t_Bool}
 };
 static OptionStruct desc[] =
 {
-	{"-speed num", "Speed"},
+	{(char *) "-speed num", (char *) "Speed"},
 #if 0
 #ifdef HAVE_XDBE_EXTENSION
-	{"-/+dbuf", "turn on/off double buffering"},
+	{(char *) "-/+dbuf", (char *) "turn on/off double buffering"},
 #endif				/* HAVE_XDBE_EXTENSION */
 #endif
-	{"-/+rrandom", "turn on/off random"}
+	{(char *) "-/+rrandom", (char *) "turn on/off random"}
 };
 
 ModeSpecOpt kumppa_opts =
