@@ -72,16 +72,16 @@ static Bool totalistic;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-totalistic", ".life1d.totalistic", XrmoptionNoArg, (caddr_t) "on"},
-	{"+totalistic", ".life1d.totalistic", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-totalistic", (char *) ".life1d.totalistic", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+totalistic", (char *) ".life1d.totalistic", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
-{(caddr_t *) & totalistic, "totalistic", "Totalistic", DEF_TOTALISTIC, t_Bool}
+{(caddr_t *) & totalistic, (char *) "totalistic", (char *) "Totalistic", (char *) DEF_TOTALISTIC, t_Bool}
 };
 static OptionStruct desc[] =
 {
-	{"-/+totalistic", "turn on/off totalistic rules (else LCAU rules)"}
+	{(char *) "-/+totalistic", (char *) "turn on/off totalistic rules (else LCAU rules)"}
 };
 
 ModeSpecOpt life1d_opts =
