@@ -76,18 +76,18 @@ static char *lifefile;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-rule", ".life3d.rule", XrmoptionSepArg, (caddr_t) NULL},
-	{"-lifefile", ".life3d.lifefile", XrmoptionSepArg, (caddr_t) NULL}
+	{(char *) "-rule", (char *) ".life3d.rule", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-lifefile", (char *) ".life3d.lifefile", XrmoptionSepArg, (caddr_t) NULL}
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & rule, "rule", "Rule", DEF_RULE, t_String},
-	{(caddr_t *) & lifefile, "lifefile", "LifeFile", "", t_String}
+	{(caddr_t *) & rule, (char *) "rule", (char *) "Rule", (char *) DEF_RULE, t_String},
+	{(caddr_t *) & lifefile, (char *) "lifefile", (char *) "LifeFile", (char *) "", t_String}
 };
 static OptionStruct desc[] =
 {
-	{"-rule string", "S<survial_neighborhood>/B<birth_neighborhood> parameters"},
-	{"-lifefile file", "life file"},
+	{(char *) "-rule string", (char *) "S<survial_neighborhood>/B<birth_neighborhood> parameters"},
+	{(char *) "-lifefile file", (char *) "life file"},
 };
 
 ModeSpecOpt life3d_opts =
