@@ -34,8 +34,9 @@ static const char sccsid[] = "@(#)mandelbrot.c 4.13 98/12/21 xlockmore";
  * Pickover.  These would make nice additions to add.
  *
  * Revision History:
- * 24-Mar-99: DEM and Binary decomp options added by Tim.Auckland@Sun.COM
- *            Ideas from Peitgen & Saupe's "The Science of Fractal Images"
+ * 24-Mar-99: DEM and Binary decomp options added by Tim Auckland
+ *            <Tim.Auckland@Procket.com>.  Ideas from Peitgen & Saupe's
+ *            "The Science of Fractal Images"
  * 20-Oct-97: Written by Dan Stromberg <strombrg@nis.acs.uci.edu>
  * 17-Nov-98: Many Changes by Stromberg, including selection of
  *            interesting subregions, more extreme color ranges,
@@ -89,24 +90,24 @@ static Bool  dem;
 
 static XrmOptionDescRec opts[] =
 {
-     {"-increment", ".mandelbrot.increment", XrmoptionSepArg, (caddr_t) NULL},
-     {"-binary", ".mandelbrot.binary", XrmoptionNoArg, (caddr_t) "on"},
-     {"+binary", ".mandelbrot.binary", XrmoptionNoArg, (caddr_t) "off"},
-     {"-dem", ".mandelbrot.dem", XrmoptionNoArg, (caddr_t) "on"},
-     {"+dem", ".mandelbrot.dem", XrmoptionNoArg, (caddr_t) "off"}
+     {(char *) "-increment", (char *) ".mandelbrot.increment", XrmoptionSepArg, (caddr_t) NULL},
+     {(char *) "-binary", (char *) ".mandelbrot.binary", XrmoptionNoArg, (caddr_t) "on"},
+     {(char *) "+binary", (char *) ".mandelbrot.binary", XrmoptionNoArg, (caddr_t) "off"},
+     {(char *) "-dem", (char *) ".mandelbrot.dem", XrmoptionNoArg, (caddr_t) "on"},
+     {(char *) "+dem", (char *) ".mandelbrot.dem", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
- {(caddr_t *) & increment, "increment", "Increment", DEF_INCREMENT, t_Float},
- {(caddr_t *) & binary, "binary", "Binary", DEF_BINARY, t_Bool},
- {(caddr_t *) & dem, "dem", "Dem", DEF_DEM, t_Bool},
+ {(caddr_t *) & increment, (char *) "increment", (char *) "Increment", (char *) DEF_INCREMENT, t_Float},
+ {(caddr_t *) & binary, (char *) "binary", (char *) "Binary", (char *) DEF_BINARY, t_Bool},
+ {(caddr_t *) & dem, (char *) "dem", (char *) "Dem", (char *) DEF_DEM, t_Bool},
 };
 static OptionStruct desc[] =
 {
-	{"-increment value", "increasing orders"},
-	{"-/+binary", "turn on/off Binary Decomposition colour modulation"},
-	{"-/+dem", "turn on/off Distance Estimator Method (instead of escape time)"}
+	{(char *) "-increment value", (char *) "increasing orders"},
+	{(char *) "-/+binary", (char *) "turn on/off Binary Decomposition colour modulation"},
+	{(char *) "-/+dem", (char *) "turn on/off Distance Estimator Method (instead of escape time)"}
 };
 
 ModeSpecOpt mandelbrot_opts =
