@@ -29,7 +29,7 @@ static const char sccsid[] = "@(#)nose.c	4.07 97/11/24 xlockmore";
  *		references to onepause, now uses MI_PAUSE(mi) interface.
  *		Ron Hitchens <ron@idiom.com>
  * 10-Oct-95: A better way of handling fortunes from a file, thanks to
- *            Jouk Jansen <joukj@crys.chem.uva.nl>.
+ *            Jouk Jansen <joukj@hrem.stm.tudelft.nl>.
  * 21-Sep-95: font option added, debugged for multiscreens
  * 12-Aug-95: xlock version
  * 1992: xscreensaver version, noseguy (Jamie Zawinski <jwz@jwz.org>)
@@ -67,6 +67,8 @@ static const char sccsid[] = "@(#)nose.c	4.07 97/11/24 xlockmore";
 #endif /* STANDALONE */
 #include "iostuff.h"
 
+#ifdef MODE_nose
+
 ModeSpecOpt nose_opts =
 {0, NULL, 0, NULL, NULL};
 
@@ -91,8 +93,6 @@ ModStruct   nose_description =
 #include "bitmaps/nose-stepl.xbm"
 #include "bitmaps/nose-stepr.xbm"
 
-#define font_height(f) ((f == None) ? 8 : f->ascent + f->descent)
-
 #define L 0
 #define R 1
 #define LSTEP 2
@@ -107,7 +107,11 @@ ModStruct   nose_description =
 #define TALK 1
 #define FREEZE 2
 
+#ifndef USE_MB
 extern XFontStruct *getFont(Display * display);
+#else
+extern XFontSet getFontSet(Display * display);
+#endif
 extern char *getWords(int screen, int screens);
 extern int  isRibbon(void);
 
@@ -134,7 +138,25 @@ typedef struct {
 
 static nosestruct *noses = NULL;
 
+#ifndef USE_MB
 static XFontStruct *mode_font = None;
+#else
+static XFontSet mode_font = None;
+#endif
+
+#ifndef USE_MB
+#define font_height(f) ((f == None) ? 8 : f->ascent + f->descent)
+#else
+static int font_height(XFontSet f) {
+  XRectangle ink, log;
+  if (f == None) {
+	return 8;
+  } else {
+	XmbTextExtents(mode_font, "M", strlen("M"), &ink, &log);
+	return log.height;
+  }
+}
+#endif
 
 #define LEFT 001
 #define RIGHT 002
@@ -468,6 +490,9 @@ talk(ModeInfo * mi, Bool force_erase)
 	int         width = 0, height, Y, Z, total = 0;
 	register char *p, *p2;
 	char        buf[BUFSIZ], args[MAXLINES][MAXWIDTH];
+#ifdef USE_MB
+	XRectangle ink, log;
+#endif
 
 	/* clear what we've written */
 	if (np->talking || force_erase) {
@@ -489,8 +514,14 @@ talk(ModeInfo * mi, Bool force_erase)
 		args[0][MAXWIDTH - 1] = '\0';
 		if (mode_font == None)
 			width = 8;
-		else
+		else {
+#ifndef USE_MB
 			width = XTextWidth(mode_font, np->words, total);
+#else
+			XmbTextExtents(mode_font, np->words, total, &ink, &log);
+			width = ink.width;
+#endif
+		}
 		height = 0;
 	} else
 		/* p2 now points to the first '\n' */
@@ -498,8 +529,14 @@ talk(ModeInfo * mi, Bool force_erase)
 			int         w;
 
 			*p2 = 0;
+#ifndef USE_MB
 			if (mode_font != None && (w = XTextWidth(mode_font, p, p2 - p)) > width)
 				width = w;
+#else
+			XmbTextExtents(mode_font, p, p2 - p, &ink, &log);
+			if (mode_font != None && (w = log.width) > width)
+			  width = w;
+#endif
 			total += p2 - p;	/* total chars; count to determine reading time */
 			(void) strncpy(args[height], p, MAXWIDTH - 1);
 			args[height][MAXWIDTH - 1] = '\0';
@@ -540,8 +577,13 @@ talk(ModeInfo * mi, Bool force_erase)
 
 	/* now print each string in reverse order (start at bottom of box) */
 	for (Z = 0; Z < height; Z++) {
+#ifndef USE_MB
 		(void) XDrawString(display, window, np->text_fg_gc,
 			np->s.x + 15, np->s.y + Y, args[Z], strlen(args[Z]));
+#else
+		(void) XmbDrawString(display, window, mode_font, np->text_fg_gc,
+							 np->s.x + 15, np->s.y + Y, args[Z], strlen(args[Z]));
+#endif
 		Y += font_height(mode_font);
 	}
 	np->busyLoop = (total / 15) * 10;
@@ -683,23 +725,40 @@ init_nose(ModeInfo * mi)
 	/* don't want any exposure events from XCopyPlane */
 	XSetGraphicsExposures(display, gc, False);
 
-	if (mode_font == None)
+	if (mode_font == None) {
+#ifndef USE_MB
 		mode_font = getFont(display);
+#else
+		mode_font = getFontSet(display);
+#endif
+	}
 	if (np->noseGC[0] == NULL)
 		pickClothes(mi);
 	np->words = getWords(MI_SCREEN(mi), MI_NUM_SCREENS(mi));
 	if (np->text_fg_gc == NULL && mode_font != None) {
+#ifndef USE_MB
 		gcv.font = mode_font->fid;
 		XSetFont(display, gc, mode_font->fid);
+#endif
 		gcv.graphics_exposures = False;
 		gcv.foreground = MI_WHITE_PIXEL(mi);
 		gcv.background = MI_BLACK_PIXEL(mi);
+#ifndef USE_MB
 		np->text_fg_gc = XCreateGC(display, window,
 					   GCForeground | GCBackground | GCGraphicsExposures | GCFont, &gcv);
+#else
+		np->text_fg_gc = XCreateGC(display, window,
+					   GCForeground | GCBackground | GCGraphicsExposures, &gcv);
+#endif
 		gcv.foreground = MI_BLACK_PIXEL(mi);
 		gcv.background = MI_WHITE_PIXEL(mi);
+#ifndef USE_MB
 		np->text_bg_gc = XCreateGC(display, window,
 					   GCForeground | GCBackground | GCGraphicsExposures | GCFont, &gcv);
+#else
+		np->text_bg_gc = XCreateGC(display, window,
+					   GCForeground | GCBackground | GCGraphicsExposures, &gcv);
+#endif
 	}
 	np->up = 1;
 	if (np->tinymode) {
@@ -766,7 +825,11 @@ release_nose(ModeInfo * mi)
 		noses = NULL;
 	}
 	if (mode_font != None) {
+#ifndef USE_MB
 		XFreeFont(MI_DISPLAY(mi), mode_font);
+#else
+		XFreeFontSet(MI_DISPLAY(mi), mode_font);
+#endif
 		mode_font = None;
 	}
 }
@@ -776,3 +839,5 @@ refresh_nose(ModeInfo * mi)
 {
 	MI_CLEARWINDOW(mi);
 }
+
+#endif /* MODE_nose */
