@@ -107,7 +107,6 @@ typedef struct {
 	int         incx, incy;
 	GC          stippledGC;
 	Pixmap      ghostPixmap;
-	int         ghostWidth, ghostHeight;
 	int         graphics_format;
 	beingstruct pacman;
 	beingstruct *ghosts;
@@ -307,13 +306,12 @@ movepac(ModeInfo * mi)
 
 		dir = (ABS(p.cfactor) * (2 - p.cfactor) +
 		       ABS(p.rfactor) * (1 + p.rfactor)) % 4;
-		XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+		XSetForeground(display, pp->stippledGC, MI_BLACK_PIXEL(mi));
 #ifdef FLASH
-		XFillRectangle(display, window, gc,
-			       p.oldcf, p.oldrf,
-			       pp->xs, pp->ys);
+		XFillRectangle(display, window, pp->stippledGC,
+			     p.oldcf, p.oldrf, pp->xs, pp->ys);
 #else
-		ERASE_IMAGE(display, window, gc, p.cf, p.rf,
+		ERASE_IMAGE(display, window, pp->stippledGC, p.cf, p.rf,
 			    p.oldcf, p.oldrf, pp->xs, pp->ys);
 #endif
 		XSetTSOrigin(display, pp->stippledGC, p.cf, p.rf);
@@ -346,42 +344,31 @@ movepac(ModeInfo * mi)
 					delta.x * g[ghost].cfactor + pp->xb;
 				g[ghost].rf = pp->ghosts[ghost].row * pp->ys +
 					delta.y * g[ghost].rfactor + pp->yb;
-				XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
-				if (pp->pixelmode) {
-					XFillRectangle(display, window, gc,
-					      g[ghost].oldcf, g[ghost].oldrf,
-						       pp->xs, pp->ys);
-					if (MI_NPIXELS(mi) > 2)
-						XSetForeground(display, gc, MI_PIXEL(mi, BLUE));
-					else
-						XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
-					XFillRectangle(display, window, gc,
-						       g[ghost].cf, g[ghost].rf, pp->xs, pp->ys);
-					XFlush(display);
-				} else {
+				XSetForeground(display, pp->stippledGC, MI_BLACK_PIXEL(mi));
 #ifdef FLASH
-					XFillRectangle(display, window, gc,
-					      g[ghost].oldcf, g[ghost].oldrf,
-						       pp->xs, pp->ys);
+				XFillRectangle(display, window, pp->stippledGC,
+				    g[ghost].oldcf, g[ghost].oldrf, pp->xs, pp->ys);
 #else
-					ERASE_IMAGE(display, window, gc, g[ghost].cf, g[ghost].rf,
-						    g[ghost].oldcf, g[ghost].oldrf, pp->xs, pp->ys);
+				ERASE_IMAGE(display, window, pp->stippledGC,
+					g[ghost].cf, g[ghost].rf,
+					g[ghost].oldcf, g[ghost].oldrf, pp->xs, pp->ys);
 #endif
-					XSetTSOrigin(display, pp->stippledGC, g[ghost].cf, g[ghost].rf);
-					if (MI_NPIXELS(mi) > 2)
-						XSetForeground(display, pp->stippledGC, MI_PIXEL(mi, BLUE));
-					else
-						XSetForeground(display, pp->stippledGC, MI_WHITE_PIXEL(mi));
-					XSetStipple(display, pp->stippledGC, pp->ghostPixmap);
+				XSetTSOrigin(display, pp->stippledGC,
+					g[ghost].cf, g[ghost].rf);
+				if (MI_NPIXELS(mi) > 2)
+					XSetForeground(display, pp->stippledGC, MI_PIXEL(mi, BLUE));
+				else
+					XSetForeground(display, pp->stippledGC, MI_WHITE_PIXEL(mi));
+				XSetStipple(display, pp->stippledGC, pp->ghostPixmap);
+
 #ifdef FLASH
-					XSetFillStyle(display, pp->stippledGC, FillStippled);
+				XSetFillStyle(display, pp->stippledGC, FillStippled);
 #else
-					XSetFillStyle(display, pp->stippledGC, FillOpaqueStippled);
+				XSetFillStyle(display, pp->stippledGC, FillOpaqueStippled);
 #endif
-					XFillRectangle(display, window, pp->stippledGC,
-						       g[ghost].cf, g[ghost].rf, pp->xs, pp->ys);
-					XFlush(display);
-				}
+				XFillRectangle(display, window, pp->stippledGC,
+			       g[ghost].cf, g[ghost].rf, pp->xs, pp->ys);
+				XFlush(display);
 				g[ghost].oldcf = g[ghost].cf;
 				g[ghost].oldrf = g[ghost].rf;
 			}
@@ -413,12 +400,12 @@ movepac(ModeInfo * mi)
 			     (pp->ghosts[ghost].row == pp->pacman.nextrow) &&
 			     (pp->ghosts[ghost].col == pp->pacman.nextcol))) {
 				pp->ghosts[ghost].dead = 1;
-				XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+				XSetForeground(display, pp->stippledGC, MI_BLACK_PIXEL(mi));
 				/*XFillRectangle(display, window, gc,
 				   pp->ghosts[ghost].col * pp->xs + pp->xb,
 				   pp->ghosts[ghost].row * pp->ys + pp->yb,
 				   pp->xs, pp->ys); */
-				XFillRectangle(display, window, gc,
+				XFillRectangle(display, window, pp->stippledGC,
 				 pp->ghosts[ghost].nextcol * pp->xs + pp->xb,
 				 pp->ghosts[ghost].nextrow * pp->ys + pp->yb,
 					       pp->xs, pp->ys);
@@ -466,36 +453,38 @@ init_pacman(ModeInfo * mi)
 	pp = &pacmangames[MI_SCREEN(mi)];
 	pp->width = MI_WIDTH(mi);
 	pp->height = MI_HEIGHT(mi);
-	if (pp->stippledGC == None) {
-		gcv.foreground = MI_BLACK_PIXEL(mi);
-		gcv.background = MI_BLACK_PIXEL(mi);
-		if ((pp->stippledGC = XCreateGC(display, window,
-				 GCForeground | GCBackground, &gcv)) == None)
-			return;
-		pp->ghostWidth = CELL_WIDTH;
-		pp->ghostHeight = CELL_HEIGHT;
-		if (size == 0) {
-			if (pp->ghostPixmap == None) {
-				getPixmap(mi, window, CELL_WIDTH, CELL_HEIGHT, CELL_BITS,
-					  &(pp->ghostWidth), &(pp->ghostHeight), &(pp->ghostPixmap),
-					  &(pp->graphics_format));
-				pp->xs = pp->ghostWidth;
-				pp->ys = pp->ghostHeight;
-			}
-		}
+	if (pp->ghostPixmap != None) {
+		XFreePixmap(display, pp->ghostPixmap);
+		pp->ghostPixmap = None;
+	    pp->graphics_format = IS_NONE;
 	}
-	if (size == 0) {
-		if (MINGRIDSIZE * pp->ghostWidth > pp->width ||
-		    MINGRIDSIZE * pp->ghostHeight > pp->height) {
-			pp->pixelmode = 1;
-			pp->xs = pp->ys = MAX(MINSIZE, MIN(pp->width, pp->height) / MINGRIDSIZE);
-		} else {
-			pp->pixelmode = 0;
-			pp->xs = pp->ghostWidth;
-			pp->ys = pp->ghostHeight;
-		}
+	if (size == 0 ||
+		MINGRIDSIZE * size > pp->width ||
+		MINGRIDSIZE * size > pp->height) {
+	    int         ghostWidth, ghostHeight;
+
+		ghostWidth = CELL_WIDTH;
+		ghostHeight = CELL_HEIGHT;
+		getPixmap(mi, window, CELL_WIDTH, CELL_HEIGHT, CELL_BITS,
+			&ghostWidth, &ghostHeight, &(pp->ghostPixmap),
+			&(pp->graphics_format));
+		pp->xs = ghostWidth;
+		pp->ys = ghostHeight;
+		if (pp->width > MINGRIDSIZE * pp->xs &&
+            pp->height > MINGRIDSIZE * pp->ys) {
+            pp->pixelmode = False;
+        } else {
+			if (pp->ghostPixmap != None) {
+				XFreePixmap(display, pp->ghostPixmap);
+				pp->ghostPixmap = None;
+			    pp->graphics_format = IS_NONE;
+			}
+            pp->pixelmode = True;
+            pp->ys = MAX(MINSIZE, MIN(pp->width, pp->height) / MINGRIDSIZE);
+            pp->xs = pp->ys;
+        }
 	} else {
-		pp->pixelmode = 1;
+		pp->pixelmode = True;
 		if (size < -MINSIZE)
 			pp->ys = NRAND(MIN(-size, MAX(MINSIZE, MIN(pp->width, pp->height) /
 				      MINGRIDSIZE)) - MINSIZE + 1) + MINSIZE;
@@ -513,32 +502,60 @@ init_pacman(ModeInfo * mi)
 	pp->xb = pp->width - pp->ncols * pp->xs;
 	pp->yb = pp->height - pp->nrows * pp->ys;
 
+	if (pp->pixelmode) {
+        pp->ghostPixmap = XCreatePixmap(display, window,
+            pp->xs, pp->ys, 1);
+        gcv.foreground = 0;
+        gcv.background = 1;
+        bg_gc = XCreateGC(display, pp->ghostPixmap,
+			GCForeground | GCBackground, &gcv);
+        gcv.foreground = 1;
+        gcv.background = 0;
+        fg_gc = XCreateGC(display, pp->ghostPixmap,
+			GCForeground | GCBackground, &gcv);
+        XFillRectangle(display, pp->ghostPixmap, bg_gc,
+            0, 0, pp->xs, pp->ys);
+		XFillArc(display, pp->ghostPixmap, fg_gc,
+			0, 0, pp->xs, pp->ys, 0, 11520);
+		XFillRectangle(display, pp->ghostPixmap, fg_gc,
+			0, pp->ys / 2, pp->xs, pp->ys / 2);
+        XFreeGC(display, bg_gc);
+        XFreeGC(display, fg_gc);
+    }
+	if (!pp->stippledGC) {
+		gcv.foreground = MI_BLACK_PIXEL(mi);
+		gcv.background = MI_BLACK_PIXEL(mi);
+		if ((pp->stippledGC = XCreateGC(display, window,
+				GCForeground | GCBackground, &gcv)) == None)
+			return;
+	}
 	if (pp->pacmanPixmap[0][0] != None)
 		for (dir = 0; dir < 4; dir++)
 			for (mouth = 0; mouth < MAXMOUTH; mouth++)
 				XFreePixmap(display, pp->pacmanPixmap[dir][mouth]);
 
-
 	for (dir = 0; dir < 4; dir++)
 		for (mouth = 0; mouth < MAXMOUTH; mouth++) {
 			pp->pacmanPixmap[dir][mouth] = XCreatePixmap(display, MI_WINDOW(mi),
 							  pp->xs, pp->ys, 1);
 			gcv.foreground = 1;
+        	gcv.background = 0;
 			fg_gc = XCreateGC(display, pp->pacmanPixmap[dir][mouth],
-					  GCForeground, &gcv);
+				GCForeground | GCBackground, &gcv);
 			gcv.foreground = 0;
+        	gcv.background = 0;
 			bg_gc = XCreateGC(display, pp->pacmanPixmap[dir][mouth],
-					  GCForeground, &gcv);
+				GCForeground | GCBackground, &gcv);
 			XFillRectangle(display, pp->pacmanPixmap[dir][mouth], bg_gc,
-				       0, 0, pp->xs, pp->ys);
+				0, 0, pp->xs, pp->ys);
 			if (pp->xs == 1 && pp->ys == 1)
 				XFillRectangle(display, pp->pacmanPixmap[dir][mouth], fg_gc,
-					       0, 0, pp->xs, pp->ys);
+					0, 0, pp->xs, pp->ys);
 			else
 				XFillArc(display, pp->pacmanPixmap[dir][mouth], fg_gc,
-					 0, 0, pp->xs, pp->ys,
-					 ((90 - dir * 90) + mouth * 5) * 64,
-					 (360 + (-2 * mouth * 5)) * 64);
+					0, 0, pp->xs, pp->ys,
+					((90 - dir * 90) + mouth * 5) * 64,
+					(360 + (-2 * mouth * 5)) * 64);
 			XFreeGC(display, fg_gc);
 			XFreeGC(display, bg_gc);
 		}
@@ -726,8 +743,9 @@ release_pacman(ModeInfo * mi)
 			if (pp->eaten != NULL)
 				(void) free((void *) pp->eaten);
 #endif
-			if (pp->stippledGC != None)
+			if (pp->stippledGC != NULL) {
 				XFreeGC(display, pp->stippledGC);
+			}
 			if (pp->ghostPixmap != None)
 				XFreePixmap(display, pp->ghostPixmap);
 			if (pp->pacmanPixmap[0][0] != None)
