@@ -82,16 +82,16 @@ static Bool ammann;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-ammann", ".penrose.ammann", XrmoptionNoArg, (caddr_t) "on"},
-	{"+ammann", ".penrose.ammann", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-ammann", (char *) ".penrose.ammann", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+ammann", (char *) ".penrose.ammann", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & ammann, "ammann", "Ammann", DEF_AMMANN, t_Bool}
+	{(caddr_t *) & ammann, (char *) "ammann", (char *) "Ammann", (char *) DEF_AMMANN, t_Bool}
 };
 static OptionStruct desc[] =
 {
-	{"-/+ammann", "turn on/off Ammann lines"}
+	{(char *) "-/+ammann", (char *) "turn on/off Ammann lines"}
 };
 
 ModeSpecOpt penrose_opts =
