@@ -61,20 +61,20 @@ static Bool kaleid;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-complete", ".qix.complete", XrmoptionNoArg, (caddr_t) "on"},
-	{"+complete", ".qix.complete", XrmoptionNoArg, (caddr_t) "off"},
-	{"-kaleid", ".qix.kaleid", XrmoptionNoArg, (caddr_t) "on"},
-	{"+kaleid", ".qix.kaleid", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-complete", (char *) ".qix.complete", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+complete", (char *) ".qix.complete", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-kaleid", (char *) ".qix.kaleid", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+kaleid", (char *) ".qix.kaleid", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
-      {(caddr_t *) & complete, "complete", "Complete", DEF_COMPLETE, t_Bool},
-	{(caddr_t *) & kaleid, "kaleid", "Kaleid", DEF_KALEID, t_Bool}
+      {(caddr_t *) & complete, (char *) "complete", (char *) "Complete", (char *) DEF_COMPLETE, t_Bool},
+	{(caddr_t *) & kaleid, (char *) "kaleid", (char *) "Kaleid", (char *) DEF_KALEID, t_Bool}
 };
 static OptionStruct desc[] =
 {
-	{"-/+complete", "turn on/off complete morphing graph"},
-	{"-/+kaleid", "turn on/off complete kaleidoscope"}
+	{(char *) "-/+complete", (char *) "turn on/off complete morphing graph"},
+	{(char *) "-/+kaleid", (char *) "turn on/off complete kaleidoscope"}
 };
 
 ModeSpecOpt qix_opts =
