@@ -58,30 +58,30 @@ extern Bool fullrandom;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-duration", ".random.duration", XrmoptionSepArg, (caddr_t) NULL},
-	{"-modelist", ".random.modelist", XrmoptionSepArg, (caddr_t) NULL},
-	{"-sequential", ".random.sequential", XrmoptionNoArg, (caddr_t) "on"},
-      {"+sequential", ".random.sequential", XrmoptionNoArg, (caddr_t) "off"},
-	{"-sequential", ".random.sequential", XrmoptionNoArg, (caddr_t) "on"},
-      {"+sequential", ".random.sequential", XrmoptionNoArg, (caddr_t) "off"},
-	{"-fullrandom", ".random.fullrandom", XrmoptionNoArg, (caddr_t) "on"},
-	{"+fullrandom", ".random.fullrandom", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-duration", (char *) ".random.duration", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-modelist", (char *) ".random.modelist", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-sequential", (char *) ".random.sequential", XrmoptionNoArg, (caddr_t) "on"},
+      {(char *) "+sequential", (char *) ".random.sequential", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-sequential", (char *) ".random.sequential", XrmoptionNoArg, (caddr_t) "on"},
+      {(char *) "+sequential", (char *) ".random.sequential", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-fullrandom", (char *) ".random.fullrandom", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+fullrandom", (char *) ".random.fullrandom", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & duration, "duration", "Duration", DEF_DURATION, t_Int},
-    {(caddr_t *) & modelist, "modelist", "Modelist", DEF_MODELIST, t_String},
-	{(caddr_t *) & sequential, "sequential", "Sequential", DEF_SEQUENTIAL, t_Bool},
-{(caddr_t *) & fullrandom, "fullrandom", "FullRandom", DEF_FULLRANDOM, t_Bool}
+	{(caddr_t *) & duration, (char *) "duration", (char *) "Duration", (char *) DEF_DURATION, t_Int},
+    {(caddr_t *) & modelist, (char *) "modelist", (char *) "Modelist", (char *) DEF_MODELIST, t_String},
+	{(caddr_t *) & sequential, (char *) "sequential", (char *) "Sequential", (char *) DEF_SEQUENTIAL, t_Bool},
+{(caddr_t *) & fullrandom, (char *) "fullrandom", (char *) "FullRandom", (char *) DEF_FULLRANDOM, t_Bool}
 };
 
 static OptionStruct desc[] =
 {
-	{"-duration num", "how long a mode runs before changing to another"},
-	{"-modelist string", "list of modes to randomly choose from"},
-	{"-/+sequential", "turn on/off picking of modes sequentially"},
-	{"-/+fullrandom", "turn on/off full random choice of mode-options"}
+	{(char *) "-duration num", (char *) "how long a mode runs before changing to another"},
+	{(char *) "-modelist string", (char *) "list of modes to randomly choose from"},
+	{(char *) "-/+sequential", (char *) "turn on/off picking of modes sequentially"},
+	{(char *) "-/+fullrandom", (char *) "turn on/off full random choice of mode-options"}
 };
 
 ModeSpecOpt random_opts =
@@ -92,22 +92,22 @@ ModStruct   random_description =
 {"random", "init_random", "draw_random", "release_random",
  "refresh_random", "change_random", NULL, &random_opts,
  1, 1, 1, 1, 64, 1.0, "",
-#ifdef USE_BOMB
+#ifdef MODE_run
+#ifdef MODE_bomb
+ "Shows a random mode from above except blank, run, and bomb", 0, NULL};
+#else
+ "Shows a random mode from above except blank and run", 0, NULL};
+#endif
+#else
+#ifdef MODE_bomb
  "Shows a random mode from above except blank and bomb", 0, NULL};
-
 #else
  "Shows a random mode from above except blank", 0, NULL};
-
+#endif
 #endif
 
 #endif
 
-#ifdef USE_BOMB
-#define NUMSPECIAL	3	/* bomb, blank, random */
-#else
-#define NUMSPECIAL	2	/* blank, random */
-#endif
-
 #define GC_SAVE_VALUES (GCFunction|GCLineWidth|GCLineStyle|GCCapStyle|GCJoinStyle|GCGraphicsExposures|GCFont|GCSubwindowMode)
 
 extern int  startscreen;
@@ -121,6 +121,19 @@ extern char *bitmap;
 
 #define MAXMODECHARS 14
 
+static char special_modes[][MAXMODECHARS] =
+{
+#ifdef MODE_bomb
+	"bomb",
+#endif
+#ifdef MODE_run
+	"run",
+#endif
+	"blank", "random"
+};
+
+#define NUMSPECIAL (int) (sizeof (special_modes) / sizeof (special_modes[0]))
+
 #ifdef USE_GL
 static char gl_modes[][MAXMODECHARS] =
 {
@@ -137,31 +150,34 @@ static char gl_modes[][MAXMODECHARS] =
   "gears",
 #endif
 #ifdef MODE_invert
-	"invert", 
+	"invert",
 #endif
 #ifdef MODE_lament
-	"lament", 
+	"lament",
 #endif
 #ifdef MODE_moebius
-	"moebius", 
+	"moebius",
 #endif
 #ifdef MODE_morph3d
-	"morph3d", 
+	"morph3d",
 #endif
 #ifdef MODE_pipes
-	"pipes", 
+	"pipes",
 #endif
 #ifdef MODE_rubik
-	"rubik", 
+	"rubik",
+#endif
+#ifdef MODE_skewb
+	"skewb",
 #endif
 #ifdef MODE_sproingies
-	"sproingies", 
+	"sproingies",
 #endif
 #ifdef MODE_stairs
-	"stairs", 
+	"stairs",
 #endif
 #ifdef MODE_superquadrics
-	"superquadrics", 
+	"superquadrics",
 #endif
 #ifdef MODE_text3d
 	"text3d"
@@ -223,6 +239,9 @@ static char write_modes[][MAXMODECHARS] =
 #ifdef MODE_tetris
 	"tetris",
 #endif
+#ifdef MODE_tik_tak
+	"tik_tak",
+#endif
 #ifdef MODE_tube
 	"tube"
 #endif
@@ -347,6 +366,9 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_sierpinski
 	"sierpinski",
 #endif
+#ifdef MODE_solitare
+	"spline",
+#endif
 #ifdef MODE_spline
 	"spline",
 #endif
@@ -378,7 +400,7 @@ static char nice_modes[][MAXMODECHARS] =
 	"world",
 #endif
 #ifdef MODE_worm
-	"worm", 
+	"worm",
 #endif
 #ifdef MODE_xjack
 	"xjack"
@@ -416,6 +438,9 @@ static char mouse_modes[][MAXMODECHARS] =
 #ifdef MODE_julia
 	"julia",
 #endif
+#ifdef MODE_solitare
+	"solitare",
+#endif
 #ifdef MODE_swarm
 	"swarm"
 #endif
@@ -473,6 +498,9 @@ static char fractal_modes[][MAXMODECHARS] =
 #ifdef MODE_drift
 	"drift",
 #endif
+#ifdef MODE_euler2d
+	"euler2d",
+#endif
 #ifdef MODE_flame
 	"flame",
 #endif
@@ -723,7 +751,7 @@ strpmtok(int *sign, char *str)
 static void
 parsemodelist(ModeInfo * mi)
 {
-	int         i, sign = 1, j;
+	int         i, sign = 1, j, found;
 	char       *p;
 
 	modes = (int *) calloc(numprocs - 1, sizeof (int));
@@ -732,55 +760,63 @@ parsemodelist(ModeInfo * mi)
 
 	while (p) {
 		if (!strcmp(p, "all")) {
-			for (i = 0; i < numprocs - NUMSPECIAL; i++)
-				modes[i] = (sign > 0);
+			for (i = 0; i < numprocs; i++) {
+				found = 0;
+				for (j = 0; j < NUMSPECIAL; j++)
+					if (!strcmp(special_modes[j], LockProcs[i].cmdline_arg)) {
+						found = 1; /* if found do not want on list nomatter sign */
+			      break;
+					}
+				if (!found)
+					modes[i] = (sign > 0);
+			}
 		} else if (!strcmp(p, "allgl")) {
-			for (i = 0; i < numprocs - NUMSPECIAL; i++)
+			for (i = 0; i < numprocs; i++)
 				for (j = 0; j < NUMGL; j++)
 					if (!strcmp(gl_modes[j], LockProcs[i].cmdline_arg))
 						modes[i] = (sign > 0);
 		} else if (!strcmp(p, "allxpm")) {
-			for (i = 0; i < numprocs - NUMSPECIAL; i++)
+			for (i = 0; i < numprocs; i++)
 				for (j = 0; j < NUMXPM; j++)
 					if (!strcmp(xpm_modes[j], LockProcs[i].cmdline_arg))
 						modes[i] = (sign > 0);
 		} else if (!strcmp(p, "allwrite")) {
-			for (i = 0; i < numprocs - NUMSPECIAL; i++)
+			for (i = 0; i < numprocs; i++)
 				for (j = 0; j < NUMWRITE; j++)
 					if (!strcmp(write_modes[j], LockProcs[i].cmdline_arg))
 						modes[i] = (sign > 0);
 		} else if (!strcmp(p, "allnice")) {
-			for (i = 0; i < numprocs - NUMSPECIAL; i++)
+			for (i = 0; i < numprocs; i++)
 				for (j = 0; j < NUMNICE; j++)
 					if (!strcmp(nice_modes[j], LockProcs[i].cmdline_arg))
 						modes[i] = (sign > 0);
 		} else if (!strcmp(p, "all3d")) {
-			for (i = 0; i < numprocs - NUMSPECIAL; i++)
+			for (i = 0; i < numprocs; i++)
 				for (j = 0; j < NUMUSE3D; j++)
 					if (!strcmp(use3d_modes[j], LockProcs[i].cmdline_arg))
 						modes[i] = (sign > 0);
 		} else if (!strcmp(p, "allmouse")) {
-			for (i = 0; i < numprocs - NUMSPECIAL; i++)
+			for (i = 0; i < numprocs; i++)
 				for (j = 0; j < NUMMOUSE; j++)
 					if (!strcmp(mouse_modes[j], LockProcs[i].cmdline_arg))
 						modes[i] = (sign > 0);
 		} else if (!strcmp(p, "allautomata")) {
-			for (i = 0; i < numprocs - NUMSPECIAL; i++)
+			for (i = 0; i < numprocs; i++)
 				for (j = 0; j < NUMAUTOMATA; j++)
 					if (!strcmp(automata_modes[j], LockProcs[i].cmdline_arg))
 						modes[i] = (sign > 0);
 		} else if (!strcmp(p, "allfractal")) {
-			for (i = 0; i < numprocs - NUMSPECIAL; i++)
+			for (i = 0; i < numprocs; i++)
 				for (j = 0; j < NUMFRACTAL; j++)
 					if (!strcmp(fractal_modes[j], LockProcs[i].cmdline_arg))
 						modes[i] = (sign > 0);
 		} else if (!strcmp(p, "allgeometry")) {
-			for (i = 0; i < numprocs - NUMSPECIAL; i++)
+			for (i = 0; i < numprocs; i++)
 				for (j = 0; j < NUMGEOMETRY; j++)
 					if (!strcmp(geometry_modes[j], LockProcs[i].cmdline_arg))
 						modes[i] = (sign > 0);
 		} else if (!strcmp(p, "allspace")) {
-			for (i = 0; i < numprocs - NUMSPECIAL; i++)
+			for (i = 0; i < numprocs; i++)
 				for (j = 0; j < NUMSPACE; j++)
 					if (!strcmp(space_modes[j], LockProcs[i].cmdline_arg))
 						modes[i] = (sign > 0);
@@ -801,9 +837,17 @@ parsemodelist(ModeInfo * mi)
 		if (modes[i])
 			modes[nmodes++] = i;
 	if (!nmodes) {		/* empty list */
-		for (i = 0; i < numprocs - NUMSPECIAL; i++)
-			modes[i] = i;
-		nmodes = i;
+		for (i = 0; i < numprocs; i++) {
+			found = 0;
+			for (j = 0; j < NUMSPECIAL; j++)
+				if (!strcmp(special_modes[j], LockProcs[i].cmdline_arg)) {
+					found = 1;
+		      break;
+				}
+			if (!found)
+				modes[i] = i;
+		}
+		nmodes = numprocs - NUMSPECIAL;
 	}
 	if (MI_IS_DEBUG(mi)) {
 		(void) fprintf(stderr, "%d mode%s: ", nmodes, ((nmodes == 1) ? "" : "s"));
@@ -839,7 +883,7 @@ setMode(ModeInfo * mi, int newmode)
 		randoms[i].fix = True;
 	}
 	if (MI_IS_VERBOSE(mi))
-		(void) fprintf(stderr, "mode: %s\n", LockProcs[currentmode].cmdline_arg);
+		(void) fprintf(stderr, "mode %d: %s\n", currentmode, LockProcs[currentmode].cmdline_arg);
 }
 
 void
@@ -869,7 +913,7 @@ init_random(ModeInfo * mi)
 			duration = 0;
 	}
 	if (rp->fix) {
-		fixColormap(MI_DISPLAY(mi), MI_WINDOW(mi), MI_SCREEN(mi), MI_NCOLORS(mi),
+		fixColormap(mi, MI_NCOLORS(mi),
 			MI_SATURATION(mi), MI_IS_MONO(mi), MI_IS_INSTALL(mi),
 		    MI_IS_INROOT(mi), MI_IS_INWINDOW(mi), MI_IS_VERBOSE(mi));
 		rp->fix = False;
@@ -901,7 +945,7 @@ draw_random(ModeInfo * mi)
 		change_now = False;
 	}
 	if (rp->fix) {
-		fixColormap(MI_DISPLAY(mi), MI_WINDOW(mi), MI_SCREEN(mi), MI_NCOLORS(mi),
+		fixColormap(mi, MI_NCOLORS(mi),
 			MI_SATURATION(mi), MI_IS_MONO(mi), MI_IS_INSTALL(mi),
 		    MI_IS_INROOT(mi), MI_IS_INWINDOW(mi), MI_IS_VERBOSE(mi));
 		rp->fix = False;
