@@ -191,13 +191,13 @@ drawSuit(ModeInfo * mi, Suits suit, int x, int y, int width, int height)
 			XFillArc(display, window, gc,
 				x + width / 2 - 1, y, width / 2, height / 2, 0, 23040);
 			polygon[0].x =  x + width / 2;
-			polygon[0].y =  y + height / 4;
+			polygon[0].y =  y + short(float(height) / 4.1);
 			polygon[1].x =  short(float(-width) / 2.7);
-			polygon[1].y =  height / 4;
+			polygon[1].y =  short(float(height) / 4.1);
 			polygon[2].x =  short(float(width) / 2.7);
-			polygon[2].y =  height / 2;
+			polygon[2].y =  short(float(height) / 2.05);
 			polygon[3].x =  short(float(width) / 2.7);
-			polygon[3].y =  -height / 2;
+			polygon[3].y =  short(float(-height) / 2.05);
 			XFillPolygon(display, window, gc,
 				polygon, 4, Convex, CoordModePrevious);
 			break;
@@ -1193,30 +1193,29 @@ extern "C" { void change_solitare(ModeInfo * mi); }
 extern "C" { void release_solitare(ModeInfo * mi); }
 extern "C" { void refresh_solitare(ModeInfo * mi); }
 
+#ifndef DISABLE_INTERACTIVE
 static XrmOptionDescRec opts[] =
 {
-#ifndef DISABLE_INTERACTIVE
 	{(char *) "-trackmouse", (char *) ".solitare.trackmouse", XrmoptionNoArg, (caddr_t) "on"},
 	{(char *) "+trackmouse", (char *) ".solitare.trackmouse", XrmoptionNoArg, (caddr_t) "off"}
-#endif
 };
 
 static argtype vars[] =
 {
-#ifndef DISABLE_INTERACTIVE
 	{(caddr_t *) & trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool}
-#endif
 };
 
 static OptionStruct desc[] =
 {
-#ifndef DISABLE_INTERACTIVE
 	{(char *) "-/+trackmouse", (char *) "turn on/off the tracking of the mouse"}
-#endif
 };
 
 ModeSpecOpt solitare_opts =
 {sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
+#else
+ModeSpecOpt solitare_opts =
+{0, NULL, 0, NULL, NULL};
+#endif
 
 #ifdef USE_MODULES
 ModStruct solitare_description =
