@@ -73,18 +73,18 @@ static Bool erase;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-erase", ".spline.erase", XrmoptionNoArg, (caddr_t) "on"},
-	{"+erase", ".spline.erase", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-erase", (char *) ".spline.erase", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+erase", (char *) ".spline.erase", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & erase, "erase", "Erase", DEF_ERASE, t_Bool}
+	{(caddr_t *) & erase, (char *) "erase", (char *) "Erase", (char *) DEF_ERASE, t_Bool}
 };
 
 static OptionStruct desc[] =
 {
-	{"-/+erase", "turn on/off the following erase of splines"}
+	{(char *) "-/+erase", (char *) "turn on/off the following erase of splines"}
 };
 
 ModeSpecOpt spline_opts =
