@@ -58,6 +58,11 @@ static const char sccsid[] = "@(#)t3d.c	1.0 2000/01/26 xlockmore";
 #include "color.h"
 #endif /* STANDALONE */
 
+#ifdef TIME_WITH_SYS_TIME /* for sco */
+#include <time.h>
+#include <sys/time.h>
+#endif
+
 #ifdef MODE_t3d
 
 #define DEF_TRACKMOUSE  "False"
@@ -113,24 +118,24 @@ static XrmOptionDescRec opts[] =
 
 static argtype vars[] =
 {
-	{(caddr_t *) & cycle_p, "cycle", "Cycle", DEF_CYCLE, t_Bool},
-	{(caddr_t *) & move, "move", "Move", DEF_MOVE, t_Float},
-	{(caddr_t *) & wobble, "wobble", "Wobble", DEF_WOBBLE, t_Float},
-	{(caddr_t *) & mag, "mag", "Magnification", DEF_MAG, t_Float},
-	{(caddr_t *) & fastch, "fast", "Fast", DEF_FAST, t_Int},
-        {(caddr_t *) & minutes, "minutes", "Minutes", DEF_MINUTES, t_Bool},
-        {(caddr_t *) & trackmouse, "trackmouse", "TrackMouse", DEF_TRACKMOUSE, t_Bool}
+	{(caddr_t *) & cycle_p, (char *) "cycle", (char *) "Cycle", (char *) DEF_CYCLE, t_Bool},
+	{(caddr_t *) & move, (char *) "move", (char *) "Move", (char *) DEF_MOVE, t_Float},
+	{(caddr_t *) & wobble, (char *) "wobble", (char *) "Wobble", (char *) DEF_WOBBLE, t_Float},
+	{(caddr_t *) & mag, (char *) "mag", (char *) "Magnification", (char *) DEF_MAG, t_Float},
+	{(caddr_t *) & fastch, (char *) "fast", (char *) "Fast", (char *) DEF_FAST, t_Int},
+        {(caddr_t *) & minutes, (char *) "minutes", (char *) "Minutes", (char *) DEF_MINUTES, t_Bool},
+        {(caddr_t *) & trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool}
 };
 
 static OptionStruct desc[] =
 {
-	{"-/+cycle", "turn on/off colour cycling"},
-	{"-move num", "Move speed"},
-	{"-wobble num", "Wobble speed"},
-	{"-mag num", "Magnification factor"},
-	{"-fast num", "Fast"},
-        {"-/+minutes", "turn on/off minutes"},
-        {"-/+trackmouse", "turn on/off the tracking of the mouse"}
+	{(char *) "-/+cycle", (char *) "turn on/off colour cycling"},
+	{(char *) "-move num", (char *) "Move speed"},
+	{(char *) "-wobble num", (char *) "Wobble speed"},
+	{(char *) "-mag num", (char *) "Magnification factor"},
+	{(char *) "-fast num", (char *) "Fast"},
+        {(char *) "-/+minutes", (char *) "turn on/off minutes"},
+        {(char *) "-/+trackmouse", (char *) "turn on/off the tracking of the mouse"}
 };
 
 ModeSpecOpt t3d_opts =
@@ -179,7 +184,8 @@ typedef struct {
 
 static t3dstruct *t3ds = NULL;
 
-void t3d_zeiger( ModeInfo* mi , double dist,double rad, double z, double sec,
+static void
+t3d_zeiger( ModeInfo* mi , double dist,double rad, double z, double sec,
 		int *q)
 /* Zeiger zeichnen */
 {
@@ -205,7 +211,8 @@ void t3d_zeiger( ModeInfo* mi , double dist,double rad, double z, double sec,
   *q = n;
 }
 
-void t3d_manipulate( ModeInfo* mi , double k)
+static void
+t3d_manipulate( ModeInfo* mi , double k)
 /*-----------------------------------------------------------------*
  *                           Uhr zeichnen                          *
  *-----------------------------------------------------------------*/
@@ -268,7 +275,8 @@ void t3d_manipulate( ModeInfo* mi , double k)
     }
 }
 
-double t3d_gettime (void)
+static double
+t3d_gettime (void)
 {
   struct timeval time1;
   struct tm *zeit;
@@ -287,7 +295,8 @@ double t3d_gettime (void)
 }
 
 
-void t3d__sort( ModeInfo* mi , int l, int r)
+static void
+t3d__sort( ModeInfo* mi , int l, int r)
 {
   int i,j;
   kugeldat ex;
@@ -314,14 +323,16 @@ void t3d__sort( ModeInfo* mi , int l, int r)
   if (i<r) t3d__sort ( mi , i,r);
 }
 
-void t3d_vektorprodukt(double feld1[], double feld2[], double feld3[])
+static void
+t3d_vektorprodukt(double feld1[], double feld2[], double feld3[])
 {
   feld3[0]=feld1[1]*feld2[2]-feld1[2]*feld2[1];
   feld3[1]=feld1[2]*feld2[0]-feld1[0]*feld2[2];
   feld3[2]=feld1[0]*feld2[1]-feld1[1]*feld2[0];
 }
 
-void t3d_turn(double feld1[], double feld2[], double winkel)
+static void
+t3d_turn(double feld1[], double feld2[], double winkel)
 {
   double temp[3];
   double s,ca,sa,sx1,sx2,sx3;
@@ -339,7 +350,8 @@ void t3d_turn(double feld1[], double feld2[], double winkel)
   feld1[2]=ca*(feld1[2]-sx3)+sa*temp[2]+sx3;
 }
 
-void t3d_projektion( ModeInfo* mi)
+static void
+t3d_projektion( ModeInfo* mi)
 {
   double c1[3],c2[3],k[3],x1,y1;
   double cno,cnorm/*,magnit*/;
@@ -393,7 +405,8 @@ void t3d_projektion( ModeInfo* mi)
 }
 
 
-void t3d_viewpoint( ModeInfo* mi)
+static void
+t3d_viewpoint( ModeInfo* mi)
 /* 1: Blickrichtung v;3:Ebenenmittelpunkt m
    double feld1[],feld3[]; */
 {
@@ -408,7 +421,8 @@ void t3d_viewpoint( ModeInfo* mi)
    t3dp->zaehler=norm*norm* t3dp->zoom;
 }
 
-void t3d_fill_kugel(int i, Pixmap buf, int setcol , ModeInfo* mi )
+static void
+t3d_fill_kugel(int i, Pixmap buf, int setcol , ModeInfo* mi )
 {
    t3dstruct *t3dp;
    Display    *display = MI_DISPLAY(mi);
@@ -493,7 +507,8 @@ void t3d_fill_kugel(int i, Pixmap buf, int setcol , ModeInfo* mi )
 }
 
 
-void t3d_init_kugel( ModeInfo* mi )
+static void
+t3d_init_kugel( ModeInfo* mi )
 {
    t3dstruct *t3dp;
 
@@ -508,7 +523,7 @@ void t3d_init_kugel( ModeInfo* mi )
 #	ifdef FASTCOPY
       t3dp->kugeln[i].r1=-((double) i)/2 -1;
       t3dp->kugeln[i].x1=sum1ton(i);
-      t3dp->kugeln[i].y1=((double) i)/2 +1;
+      t3dp->kugeln[i].y1=i/2 +1;
 
       t3d_fill_kugel(i,t3dp->fastcircles,1 , mi );
 /*      setink((1<<MIN(24,t3dp->depth))-1);*/
@@ -516,7 +531,7 @@ void t3d_init_kugel( ModeInfo* mi )
       t3d_fill_kugel(i,t3dp->fastmask,0 , mi );
 #	else
       t3dp->kugeln[i].r1=-((double) i)/2 -1;
-      t3dp->kugeln[i].x1=t3dp->kugeln[i].y1=((double) i)/2 +1;
+      t3dp->kugeln[i].x1=t3dp->kugeln[i].y1=i/2 +1;
 
       t3d_fill_kugel(i,t3dp->buffer,1 , mi );
       t3dp->fastcircles[i]=XGetImage(display,t3dp->buffer,0,0,i+2,i+2,
@@ -528,14 +543,15 @@ void t3d_init_kugel( ModeInfo* mi )
 				  (1<<t3dp->depth)-1,ZPixmap);
       setink(MI_BLACK_PIXEL(mi));
       XFillRectangle (display, t3dp->buffer     , t3dp->gc, 0, 0,
-		      t3dp->width, t3dp->height);	
+		      t3dp->width, t3dp->height);
 #	endif
     }
   t3dp->fastdraw=1;
 #endif
 }
 
-void t3d_init_3d( ModeInfo* mi )
+static void
+t3d_init_3d( ModeInfo* mi )
 {
    t3dstruct *t3dp;
    double i;
@@ -566,7 +582,8 @@ void t3d_init_3d( ModeInfo* mi )
 
 }
 
-void t3d_initialize( ModeInfo* mi )
+static void
+t3d_initialize( ModeInfo* mi )
 {
    Display    *display = MI_DISPLAY(mi);
    Window      window = MI_WINDOW(mi);
@@ -581,7 +598,7 @@ void t3d_initialize( ModeInfo* mi )
 
    t3dp->movef = (double) move;
    t3dp->wobber = (double) wobble;
-   t3dp->fastch = fastch * mag;
+   t3dp->fastch = (int) (fastch * mag);
    if ( t3dp->fastch > MAXFAST )
      t3dp->fastch = MAXFAST;
 
@@ -629,7 +646,7 @@ void t3d_initialize( ModeInfo* mi )
 
   setink(MI_BLACK_PIXEL(mi));
   XFillRectangle (display, t3dp->buffer , t3dp->gc, 0, 0, t3dp->width,
-		  t3dp->height);	
+		  t3dp->height);
 
 #ifdef FASTCOPY
   setink(MI_BLACK_PIXEL(mi));
@@ -686,8 +703,8 @@ init_t3d(ModeInfo * mi)
    if (!t3dp->gc)
      {
 	t3d_initialize( mi );
-	
-	
+
+
 	if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2)
 	  {
 	     XColor      color;
@@ -935,7 +952,7 @@ draw_t3d(ModeInfo * mi)
 	    }
 	}
 
-   XSync(display,0);
+   XFlush(display);
 
    XCopyArea (display, t3dp->buffer, window, t3dp->gc, 0, 0, t3dp->width,
 	      t3dp->height, 0, 0);
@@ -984,7 +1001,7 @@ draw_t3d(ModeInfo * mi)
      }
 
    if ((t3dp->px>0)&&(t3dp->px<t3dp->width)&&(t3dp->py>0)&&
-       (t3dp->py<t3dp->height) )		
+       (t3dp->py<t3dp->height) )
 	  {
 	    if ((t3dp->px !=t3dp->startx)&&( button == 2 ))
 	      {
@@ -1013,7 +1030,7 @@ draw_t3d(ModeInfo * mi)
 	  }
 	if (!( button == 1 )&&!( button == 3 ))
 	  t3dp->vturn=0;
-	
+
 	t3dp->speed=t3dp->speed+t3dp->speed*t3dp->vspeed;
 	if ((t3dp->speed<0.0000001) &&(t3dp->vspeed>0.000001)) t3dp->speed=0.000001;
 	t3dp->vspeed=.1*t3dp->vspeed;
