@@ -63,6 +63,8 @@ static const char sccsid[] = "@(#)triangle.c	4.07 97/11/24 xlockmore";
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
 
+#ifdef MODE_triangle
+
 ModeSpecOpt triangle_opts =
 {0, NULL, 0, NULL, NULL};
 
@@ -362,3 +364,5 @@ refresh_triangle(ModeInfo * mi)
 {
 	MI_CLEARWINDOW(mi);
 }
+
+#endif /* MODE_triangle */
