@@ -57,17 +57,17 @@ static int  neighbors;
 
 static XrmOptionDescRec opts[] =
 {
-        {"-neighbors", ".voters.neighbors", XrmoptionSepArg, (caddr_t) NULL}
+        {(char *) "-neighbors", (char *) ".voters.neighbors", XrmoptionSepArg, (caddr_t) NULL}
 };
 
 static argtype vars[] =
 {
-        {(caddr_t *) & neighbors, "neighbors", "Neighbors", DEF_NEIGHBORS, t_Int
+        {(caddr_t *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int
 }
 };
 static OptionStruct desc[] =
 {
-        {"-neighbors num", "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"}
+        {(char *) "-neighbors num", (char *) "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"}
 };
 
 ModeSpecOpt voters_opts =
