@@ -22,7 +22,7 @@ static const char sccsid[] = "@(#)wire.c	4.07 97/11/24 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
- * 05-Dec-97: neighbors option added. 
+ * 05-Dec-97: neighbors option added.
  * 10-May-97: Compatible with xscreensaver
  * 14-Jun-96: Coded from A.K. Dewdney's "Computer Recreations", Scientific
  *            American Magazine" Jan 1990 pp 146-148.  Used ant.c as an
@@ -32,7 +32,33 @@ static const char sccsid[] = "@(#)wire.c	4.07 97/11/24 xlockmore";
  */
 
 /*-
- * OR gate is protected by diodes
+ *  # Rules file for Wireworld
+ *
+ *  # 0 is space, 1 is wire, 2 is tail, 3 is head
+ *  states 4
+ *
+ *  passive 2
+ *  0[0123][0123][0123][0123]0	# No way to make a space into signal or wire
+ *
+ *  # Signal propagation
+ *  2[0123][0123][0123][0123]1	# tail -> wire
+ *  3[0123][0123][0123][0123]2	# head -> tail
+ *
+ *  # 1 or 2 heads adjacent to a wire makes it a head
+ *  1(3*1)3			# wire with 1 head adjacent -> head
+ *  1(3*2)3			# wire with 2 heads adjacent -> head
+ *
+ *
+ *  " " is space, X is wire, o is tail, O is head
+ *
+ *   ->XXXoOXXX-> Electron moving in a wire
+ *
+ * Diode -- permits an electron to pass right to left, but not the other way.
+ *    XX
+ *  XX XXX
+ *    XX
+ *
+ * OR gate or fan-in where inputs are protected by diodes
  *           XX     XX
  * Input ->XXX XX XX XXX<- Input
  *           XX  X  XX
@@ -42,8 +68,9 @@ static const char sccsid[] = "@(#)wire.c	4.07 97/11/24 xlockmore";
  *               V
  *             Output
  *
- *   ->XXXoOXXX-> Electron moving in a wire
- *
+ * Dewdney's synchronous-logic flipflop.
+ * Bottom left input is write 1, top left is remember 0.
+ * When gate is on, 1 electron goes to output at right every 13 cycles
  * memory element, about to forget 1 and remember 0
  *         Remember 0
  *             o
@@ -85,17 +112,17 @@ static int  neighbors;
 
 static XrmOptionDescRec opts[] =
 {
-	{"-neighbors", ".wire.neighbors", XrmoptionSepArg, (caddr_t) NULL}
+	{(char *) "-neighbors", (char *) ".wire.neighbors", XrmoptionSepArg, (caddr_t) NULL}
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & neighbors, "neighbors", "Neighbors", DEF_NEIGHBORS, t_Int
+	{(caddr_t *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int
 }
 };
 static OptionStruct desc[] =
 {
-	{"-neighbors num", "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"}
+	{(char *) "-neighbors num", (char *) "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"}
 };
 
 ModeSpecOpt wire_opts =
@@ -764,7 +791,7 @@ init_wire(ModeInfo * mi)
 		WIREBITS(stipples[NUMSTIPPLES - 1], STIPPLESIZE, STIPPLESIZE);
 		WIREBITS(stipples[NUMSTIPPLES - 3], STIPPLESIZE, STIPPLESIZE);
 		WIREBITS(stipples[2], STIPPLESIZE, STIPPLESIZE);
-		if (wp->pixmaps[2] == None) { 
+		if (wp->pixmaps[2] == None) {
 			release_wire(mi);
 			return;
 		}
