@@ -552,7 +552,6 @@ pickPixmap(Display * display, Drawable drawable, char *name,
 		*graphics_format = IS_XBM;
 		*pixmap = XCreateBitmapFromData(display, drawable,
 				     (char *) default_bits, *width, *height);
-
 	}
 }
 
@@ -826,3 +825,18 @@ getFont(Display * display)
 	}
 	return messagefont;
 }
+
+#ifdef USE_MB
+XFontSet
+getFontSet(Display * display)
+{
+	char **miss, *def;
+	int n_miss;
+	XFontSet fs;
+
+	fs = XCreateFontSet(display,
+			    DEF_MESSAGEFONTSET,
+			    &miss, &n_miss, &def);
+	return fs;
+}
+#endif
