@@ -479,6 +479,8 @@ extern void release_last_mode(ModeInfo *);
 
 /* -------------------------------------------------------------------- */
 
+/* if you just want the blank mode... how sad! */
+#ifndef BLANK_ONLY 
 /* comment out following defines to remove modes */
 #ifdef USE_GL
 #define MODE_cage
@@ -489,11 +491,14 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_stairs
 #define MODE_superquadrics
 #define MODE_sproingies
+#ifdef USE_UNSTABLE
+#define MODE_skewb /* actively underdevelopment */
 #ifdef HAVE_CXX
-#if defined( HAVE_TTF ) && defined( HAVE_GLTT ) && defined( USE_UNSTABLE )
+#if defined( HAVE_TTF ) && defined( HAVE_GLTT )
 #define MODE_text3d
 #endif
 #endif
+#endif
 #ifndef USE_MODULES
 #define MODE_atlantis
 #define MODE_bubble3d
@@ -514,7 +519,8 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_solitare
 #endif
 #ifdef USE_UNSTABLE
-#define MODE_space
+#define MODE_space /* should be combined with star some day */
+#define MODE_run /* VMS problems as well as --debug problems */
 #ifdef HAVE_CXX
 #ifdef UNDER_DEVELOPMENT
 #define MODE_billiards
@@ -548,6 +554,7 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_dilemma
 #define MODE_discrete
 #define MODE_drift
+#define MODE_euler2d
 #define MODE_eyes
 #define MODE_fadeplot
 #define MODE_flag
@@ -615,11 +622,13 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_wire
 #define MODE_world
 #define MODE_worm
+#define MODE_xcl
 #define MODE_xjack
 
 #ifdef USE_BOMB
 #define MODE_bomb
 #endif
+#endif
 
 #ifndef USE_MODULES
 
@@ -824,6 +833,14 @@ extern ModeHook refresh_drift;
 extern ModeSpecOpt drift_opts;
 #endif
 
+#ifdef MODE_euler2d
+extern ModeHook init_euler2d;
+extern ModeHook draw_euler2d;
+extern ModeHook release_euler2d;
+extern ModeHook refresh_euler2d;
+extern ModeSpecOpt euler2d_opts;
+#endif
+
 #ifdef MODE_eyes
 extern ModeHook init_eyes;
 extern ModeHook draw_eyes;
@@ -1248,6 +1265,14 @@ extern ModeHook refresh_sierpinski;
 extern ModeSpecOpt sierpinski_opts;
 #endif
 
+#ifdef MODE_skewb
+extern ModeHook init_skewb;
+extern ModeHook draw_skewb;
+extern ModeHook release_skewb;
+extern ModeHook change_skewb;
+extern ModeSpecOpt skewb_opts;
+#endif
+
 #ifdef MODE_slip
 extern ModeHook init_slip;
 extern ModeHook draw_slip;
@@ -1376,6 +1401,7 @@ extern ModeHook init_tetris;
 extern ModeHook draw_tetris;
 extern ModeHook release_tetris;
 extern ModeHook refresh_tetris;
+extern ModeHook change_tetris;
 extern ModeSpecOpt tetris_opts;
 #endif
 
@@ -1477,6 +1503,14 @@ extern ModeHook refresh_worm;
 extern ModeSpecOpt worm_opts;
 #endif
 
+#ifdef MODE_xcl
+extern ModeHook init_xcl;
+extern ModeHook draw_xcl;
+extern ModeHook release_xcl;
+extern ModeHook refresh_xcl;
+extern ModeSpecOpt xcl_opts;
+#endif
+
 #ifdef MODE_xjack
 extern ModeHook init_xjack;
 extern ModeHook draw_xjack;
@@ -1490,6 +1524,14 @@ extern ModeHook release_blank;
 extern ModeHook refresh_blank;
 extern ModeSpecOpt blank_opts;
 
+#ifdef MODE_run
+extern ModeHook init_run;
+extern ModeHook draw_run;
+extern ModeHook release_run;
+extern ModeHook refresh_run;
+extern ModeSpecOpt run_opts;
+#endif
+
 #ifdef MODE_bomb
 extern ModeHook init_bomb;
 extern ModeHook draw_bomb;
