@@ -237,6 +237,17 @@ struct itmlst {
 
 #ifdef HP_PASSWDETC		/* HAVE_SYS_WAIT_H */
 #include <sys/wait.h>
+
+/*-
+ * Potential security problem on HP with PasswdEtc
+ * This hack is totally crazy and has security holes.
+ */
+
+#if 1
+        /* Change 1 to 0 */
+        Hackers can probably get at the encrypted passwd file
+#endif
+
 #endif /* HP_PASSWDETC */
 
 #ifdef AFS
