@@ -70,39 +70,39 @@ static const char sccsid[] = "@(#)resource.c	4.08 98/08/04 xlockmore";
 #include "iostuff.h"
 #include "version.h"
 #if VMS
-#if ( __VMS_VER < 70000000 )
-#ifdef __DECC
-#define gethostname decc$gethostname
-#define gethostbyname decc$gethostbyname
-#endif
-#else
-#include <socket.h>
-#endif
+# if ( __VMS_VER < 70000000 )
+#  ifdef __DECC
+#   define gethostname decc$gethostname
+#   define gethostbyname decc$gethostbyname
+#  endif
+# else
+#  include <socket.h>
+# endif
 #endif
 
 #ifndef offsetof
-#define offsetof(s,m) ((char*)(&((s *)0)->m)-(char*)0)
+# define offsetof(s,m) ((char*)(&((s *)0)->m)-(char*)0)
 #endif
 
 #ifdef USE_MODULES
-#ifndef DEF_MODULEPATH
-#define DEF_MODULEPATH "/usr/lib/X11/xlock_modules"
-#endif
+# ifndef DEF_MODULEPATH
+#  define DEF_MODULEPATH "/usr/lib/X11/xlock_modules"
+# endif
 #endif
 
 #ifndef DEF_FILESEARCHPATH
-#ifdef VMS
-#include <descrip>
-#include <iodef>
-#include <ssdef>
-#include <stsdef>
-#include <types.h>
-#include <starlet.h>
+# ifdef VMS
+#  include <descrip>
+#  include <iodef>
+#  include <ssdef>
+#  include <stsdef>
+#  include <types.h>
+#  include <starlet.h>
 
-#define DEF_FILESEARCHPATH "DECW$SYSTEM_DEFAULTS:DECW$%N.DAT%S"
-#define BUFSIZE 132
-#define DECW$C_WS_DSP_TRANSPORT 2	/*  taken from wsdriver.lis */
-#define IO$M_WS_DISPLAY 0x00000040	/* taken from wsdriver */
+#  define DEF_FILESEARCHPATH "DECW$SYSTEM_DEFAULTS:DECW$%N.DAT%S"
+#  define BUFSIZE 132
+#  define DECW$C_WS_DSP_TRANSPORT 2	/*  taken from wsdriver.lis */
+#  define IO$M_WS_DISPLAY 0x00000040	/* taken from wsdriver */
 
 struct descriptor_t {		/* descriptor structure         */
 	unsigned short len;
@@ -114,24 +114,24 @@ typedef struct descriptor_t dsc;
 
 /* $dsc creates a descriptor for a predefined string */
 
-#define $dsc(name,string) dsc name = { sizeof(string)-1,14,1,string}
+#  define $dsc(name,string) dsc name = { sizeof(string)-1,14,1,string}
 
 /* $dscp creates a descriptor pointing to a buffer allocated elsewhere */
 
-#define $dscp(name,size,addr) dsc name = { size,14,1,addr }
+#  define $dscp(name,size,addr) dsc name = { size,14,1,addr }
 
 static int  descr();
 
-#else
-#define DEF_FILESEARCHPATH "/usr/lib/X11/%T/%N%C%S:/usr/lib/X11/%T/%N%S"
-#endif
+# else
+#  define DEF_FILESEARCHPATH "/usr/lib/X11/%T/%N%C%S:/usr/lib/X11/%T/%N%S"
+# endif
 #endif
 #ifndef DEF_MODE
-#if 0
-#define DEF_MODE	"blank"	/* May be safer */
-#else
-#define DEF_MODE	"random"	/* May be more interesting */
-#endif
+# if 0
+#  define DEF_MODE	"blank"	/* May be safer */
+# else
+#  define DEF_MODE	"random"	/* May be more interesting */
+# endif
 #endif
 #define DEF_DELAY	"200000"	/* microseconds between batches */
 #define DEF_COUNT	"100"	/* vectors (or whatever) per batch */
@@ -145,75 +145,79 @@ static int  descr();
 #define DEF_LOCKDELAY	"0"	/* secs until lock */
 #define DEF_TIMEOUT	"30"	/* secs until password entry times out */
 #ifndef DEF_FONT
-#ifdef AIXV3
-#define DEF_FONT	"fixed"
-#else /* !AIXV3 */
-#define DEF_FONT	"-b&h-lucida-medium-r-normal-sans-24-*-*-*-*-*-iso8859-1"
-#endif /* !AIXV3 */
+# ifdef AIXV3
+#  define DEF_FONT	"fixed"
+# else /* !AIXV3 */
+#  define DEF_FONT	"-b&h-lucida-medium-r-normal-sans-24-*-*-*-*-*-iso8859-1"
+# endif /* !AIXV3 */
 #endif
 #define DEF_PLANFONT     "-adobe-courier-medium-r-*-*-14-*-*-*-m-*-iso8859-1"
 #ifdef USE_MB
-#define DEF_FONTSET	DEF_FONT ## ",-*-24-*"
+# define DEF_FONTSET	DEF_FONT ## ",-*-24-*"
 #endif
 #define DEF_BG		"White"
 #define DEF_FG		"Black"
 #ifdef FR
-#define DEF_NAME	"Nom: "
-#define DEF_PASS	"Mot de passe: "
-#define DEF_VALID	"Validation ..."
-#define DEF_INVALID	"Mot de passe Invalide."
-#define DEF_INFO	"Entrez le mot de passe ou choisissez l'icone pour verrouiller."
+# define DEF_NAME	"Nom: "
+# define DEF_PASS	"Mot de passe: "
+# define DEF_VALID	"Validation ..."
+# define DEF_INVALID	"Mot de passe Invalide."
+# define DEF_INFO	"Entrez le mot de passe ou choisissez l'icone pour verrouiller."
 #else
-#ifdef NL
-#define DEF_NAME  "Naam: "
-#define DEF_PASS  "Wachtwoord: "
-#define DEF_VALID "Aan het checken ..."
-#define DEF_INVALID "Ongeldig wachtwoord."
-#define DEF_INFO  "Geef wachtwoord om te ontgrendelen ; selecteer het icoon om te vergendelen."
+#if defined NL
+# define DEF_NAME	"Naam: "
+# define DEF_PASS	"Wachtwoord: "
+# define DEF_VALID	"Aan het checken ..."
+# define DEF_INVALID	"Ongeldig wachtwoord."
+# define DEF_INFO	"Geef wachtwoord om te ontgrendelen ; selecteer het icoon om te vergendelen."
 #else
-#define DEF_NAME	"Name: "
-#define DEF_PASS	"Password: "
-#define DEF_VALID	"Validating login..."
-#define DEF_INVALID	"Invalid login."
-#define DEF_INFO	"Enter password to unlock; select icon to lock."
+#if defined JP
+# include "resource-msg-jp.h"
+#else
+# define DEF_NAME	"Name: "
+# define DEF_PASS	"Password: "
+# define DEF_VALID	"Validating login..."
+# define DEF_INVALID	"Invalid login."
+# define DEF_INFO	"Enter password to unlock; select icon to lock."
+#endif
 #endif
 #endif
 #ifdef GLOBAL_UNLOCK
-#define DEF_GUSER "Username: "
+# define DEF_GUSER "Username: "
 #endif
 #ifdef SAFEWORD
-#define DEF_DPASS "Dynamic password: "
-#define DEF_FPASS "Fixed Password: "
-#define DEF_CHALL "Challenge: "
+# define DEF_DPASS "Dynamic password: "
+# define DEF_FPASS "Fixed Password: "
+# define DEF_CHALL "Challenge: "
 #endif
 #define DEF_GEOMETRY	""
 #define DEF_ICONGEOMETRY	""
 #ifdef FX
-#define DEF_GLGEOMETRY ""
+# define DEF_GLGEOMETRY ""
 #endif
 #define DEF_DELTA3D	"1.5"	/* space between things in 3d mode relative to their size */
 #ifndef DEF_MESSAGESFILE
-#define DEF_MESSAGESFILE	""
+# define DEF_MESSAGESFILE	""
 #endif
 #ifndef DEF_MESSAGEFILE
-#define DEF_MESSAGEFILE ""
+# define DEF_MESSAGEFILE ""
 #endif
 #ifndef DEF_MESSAGE
 /* #define DEF_MESSAGE "I am out running around." */
-#define DEF_MESSAGE ""
+# define DEF_MESSAGE ""
 #endif
 #ifndef DEF_BITMAP
-#define DEF_BITMAP ""
+# define DEF_BITMAP ""
 #endif
 #ifndef DEF_MAILAPP
-#define DEF_MAILAPP ""
+# define DEF_MAILAPP ""
 #endif
 #ifdef USE_VTLOCK
-#define VTLOCKMODE_OFF     	"off"
-#define VTLOCKMODE_NOSWITCH     "noswitch"
-#define VTLOCKMODE_SWITCH       "switch"
-#define VTLOCKMODE_RESTORE      "restore"
-#define DEF_VTLOCK              VTLOCKMODE_OFF
+# define VTLOCKMODE_OFF     	"off"
+# define VTLOCKMODE_NOSWITCH     "noswitch"
+# define VTLOCKMODE_SWITCH       "switch"
+# define VTLOCKMODE_RESTORE      "restore"
+# define DEF_VTLOCK              VTLOCKMODE_OFF
 #endif
 #define DEF_CLASSNAME	"XLock"
 #if 0
@@ -224,80 +228,86 @@ static int  descr();
   Hexagon  6
   Triangle 3, 9 or 12     <- 9 is not too mathematically sound...
 */
-#define DEF_NEIGHBORS  "0"	/* automata mode will choose best or random value */
-#define DEF_MOUSE   "False"
+# define DEF_NEIGHBORS  "0"	/* automata mode will choose best or random value */
+# define DEF_MOUSE   "False"
 #endif
 
 #ifdef USE_RPLAY
-#define DEF_LOCKSOUND	"thank-you"
-#define DEF_INFOSOUND	"identify-please"
-#define DEF_VALIDSOUND	"complete"
-#define DEF_INVALIDSOUND	"not-programmed"
+# define DEF_LOCKSOUND	"thank-you"
+# define DEF_INFOSOUND	"identify-please"
+# define DEF_VALIDSOUND	"complete"
+# define DEF_INVALIDSOUND	"not-programmed"
 #else /* !USE_RPLAY */
-#if defined ( DEF_PLAY ) || defined ( USE_NAS )
-#define DEF_LOCKSOUND	"thank-you.au"
-#define DEF_INFOSOUND	"identify-please.au"
-#define DEF_VALIDSOUND	"complete.au"
-#define DEF_INVALIDSOUND	"not-programmed.au"
-#else /* !DEF_PLAY && !USE_NAS */
-#ifdef USE_VMSPLAY
-#define DEF_LOCKSOUND	"[]thank-you.au"
-#define DEF_INFOSOUND	"[]identify-please.au"
-#define DEF_VALIDSOUND	"[]complete.au"
-#define DEF_INVALIDSOUND	"[]not-programmed.au"
-#endif /* !USE_VMSPLAY */
-#ifdef USE_ESOUND
-#define DEFAULT_SOUND_DIR "/usr/lib/sounds/xlockmore"
-#define DEF_LOCKSOUND 	"thank-you.au"
-#define DEF_INFOSOUND	"identify-please.au"
-#define DEF_VALIDSOUND	"complete.au"
-#define DEF_INVALIDSOUND	"not-programmed.au"
-#endif
-#endif /* !DEF_PLAY && !USE_NAS */
+# if defined ( DEF_PLAY ) || defined ( USE_NAS )
+#  define DEF_LOCKSOUND	"thank-you.au"
+#  define DEF_INFOSOUND	"identify-please.au"
+#  define DEF_VALIDSOUND	"complete.au"
+#  define DEF_INVALIDSOUND	"not-programmed.au"
+# else /* !DEF_PLAY && !USE_NAS */
+#  ifdef USE_VMSPLAY
+#   define DEF_LOCKSOUND	"[]thank-you.au"
+#   define DEF_INFOSOUND	"[]identify-please.au"
+#   define DEF_VALIDSOUND	"[]complete.au"
+#   define DEF_INVALIDSOUND	"[]not-programmed.au"
+#  endif /* !USE_VMSPLAY */
+#  ifdef USE_ESOUND
+#   ifndef DEFAULT_SOUND_DIR
+#    define DEFAULT_SOUND_DIR "/usr/share/sounds/xlockmore"
+#   endif
+#   define DEF_LOCKSOUND 	"thank-you.au"
+#   define DEF_INFOSOUND	"identify-please.au"
+#   define DEF_VALIDSOUND	"complete.au"
+#   define DEF_INVALIDSOUND	"not-programmed.au"
+#  endif
+# endif /* !DEF_PLAY && !USE_NAS */
 #endif /* !USE_RPLAY */
 
 #if defined( USE_AUTO_LOGOUT ) && !defined( DEF_AUTO_LOGOUT )
-#if ( USE_AUTO_LOGOUT <= 0 )
-#define DEF_AUTO_LOGOUT "120"	/* User Default, can be overridden */
-#else
-#define DEF_AUTO_LOGOUT "0"	/* User Default, can be overridden */
-#endif
+# if ( USE_AUTO_LOGOUT <= 0 )
+#  define DEF_AUTO_LOGOUT "120"	/* User Default, can be overridden */
+# else
+#  define DEF_AUTO_LOGOUT "0"	/* User Default, can be overridden */
+# endif
 #endif
 
 #ifdef USE_DPMS
-#define DEF_DPMSSTANDBY "-1"
-#define DEF_DPMSSUSPEND "-1"
-#define DEF_DPMSOFF     "-1"
+# define DEF_DPMSSTANDBY "-1"
+# define DEF_DPMSSUSPEND "-1"
+# define DEF_DPMSOFF     "-1"
 #endif
 
 #if defined( USE_BUTTON_LOGOUT )
-#if !defined( DEF_BUTTON_LOGOUT )
-#if ( USE_BUTTON_LOGOUT <= 0 )
-#define DEF_BUTTON_LOGOUT "5"	/* User Default, can be overridden */
-#else
-#define DEF_BUTTON_LOGOUT "0"	/* User Default, can be overridden */
-#endif
-#endif
+# if !defined( DEF_BUTTON_LOGOUT )
+#  if ( USE_BUTTON_LOGOUT <= 0 )
+#   define DEF_BUTTON_LOGOUT "5"	/* User Default, can be overridden */
+#  else
+#   define DEF_BUTTON_LOGOUT "0"	/* User Default, can be overridden */
+#  endif
+# endif
 
-#ifdef FR
-#define DEF_BTN_LABEL	"Logout"
-#define DEF_BTN_HELP	"Cliquer ici pour etre deloger"
-#define DEF_FAIL	"Auto-logout a echoue"
-#else
+# ifdef FR
+#  define DEF_BTN_LABEL	"Logout"
+#  define DEF_BTN_HELP	"Cliquer ici pour etre deloger"
+#  define DEF_FAIL	"Auto-logout a echoue"
+# else
 #ifdef NL
-#define DEF_BTN_LABEL "Loguit"
-#define DEF_BTN_HELP  "klik hier om uit te loggen"
-#define DEF_FAIL  "Auto-loguit mislukt"
-#else
-#define DEF_BTN_LABEL	"Logout"	/* string that appears in logout button */
+#  define DEF_BTN_LABEL "Loguit"
+#  define DEF_BTN_HELP  "klik hier om uit te loggen"
+#  define DEF_FAIL  "Auto-loguit mislukt"
+# else
+#ifdef JP
+#  include "resource-msg-jp.h"
+# else
+#  define DEF_BTN_LABEL	"Logout"	/* string that appears in logout button */
 
 /* this string appears immediately below logout button */
-#define DEF_BTN_HELP	"Click here to logout"
+#  define DEF_BTN_HELP	"Click here to logout"
 
 /* this string appears in place of the logout button if user could not be
    logged out */
-#define DEF_FAIL	"Auto-logout failed"
+#  define DEF_FAIL	"Auto-logout failed"
 
+# endif
 #endif
 #endif
 #endif
@@ -318,7 +328,7 @@ Bool        mouse;
 #endif
 
 char        hostname[MAXHOSTNAMELEN];
-static char *mode;
+static char *mode = NULL;
 char       *displayname = NULL;
 static char *classname;
 static char *modename;
@@ -585,7 +595,7 @@ static OptionStruct opDesc[] =
 	{"-/+description", "whether to show mode description (yes/no)"},
 	{"-/+echokeys", "turn on/off echo '?' for each password key"},
 	{"-/+enablesaver", "turn on/off enable X server screen saver"},
-	{"-/+resetsaver", "turn on/off enable X server screen saver"},
+	{"-/+resetsaver", "turn on/off resetting of X server screen saver"},
 	{"-/+grabmouse", "turn on/off grabbing of mouse and keyboard"},
 	{"-/+grabserver", "turn on/off grabbing of server"},
 	{"-/+install", "whether to use private colormap if needed (yes/no)"},
@@ -1152,7 +1162,7 @@ GetResource(XrmDatabase database,
 	char       *type;
 	XrmValue    value;
 	char       *string;
-	char        buffer[1024];
+	char       *buffer;
 	char       *fullName;
 	char       *fullClassName;
 	int         len, temp;
@@ -1179,8 +1189,8 @@ GetResource(XrmDatabase database,
 		len = strlen(string);
 	}
 
-	(void) strncpy(buffer, string, sizeof (buffer));
-	buffer[sizeof (buffer) - 1] = '\0';
+	buffer = (char *) malloc(strlen(string) + 1);
+	(void) strcpy(buffer, string);
 
 	switch (valueType) {
 		case t_String:
@@ -1217,6 +1227,7 @@ GetResource(XrmDatabase database,
 				      !strcmp(buffer, "yes")) ? True : False;
 			break;
 	}
+	(void) free((void *) buffer);
 }
 
 static      XrmDatabase
@@ -1435,7 +1446,7 @@ checkDisplay(void)
 
 #if defined(__cplusplus) || defined(c_plusplus)		/* !__bsdi__ */
 /* #include <netdb.h> */
-#if HAVE_GETHOSTNAME
+#if !HAVE_GETHOSTNAME
 #ifdef SunCplusplus
 	extern struct hostent *gethostbyname(const char *);
 
@@ -1447,8 +1458,12 @@ checkDisplay(void)
 #endif
 #endif
 #else
+#if 1
+extern int  gethostname(char *, size_t);
+#else
 #define gethostname(name,namelen) sysinfo(SI_HOSTNAME,name,namelen)
 #endif
+#endif
 #endif
 
 	/*
@@ -1627,7 +1642,6 @@ getAppResources(char *homeenv, char **custom, XrmDatabase * RDB,
 	XrmDatabase cmdlineDB = NULL;
 	XrmDatabase userDB = NULL;
 	XrmDatabase applicationDB = NULL;
-	extern char *getenv(const char *);
 
 	env = getenv("XFILESEARCHPATH");
 	applicationDB = parsefilepath(env ? env : DEF_FILESEARCHPATH,
@@ -1721,7 +1735,6 @@ getResources(Display ** displayp, int argc, char **argv)
 	char       *homeenv = NULL;
 	int         i, j;
 	int         max_length;
-	extern char *getenv(const char *);
 extern void XlockrmParseCommand(
     XrmDatabase		*pdb,		/* data base */
     register XrmOptionDescList options, /* pointer to table of valid options */
@@ -1954,6 +1967,10 @@ extern void XlockrmParseCommand(
    * line.  PURIFY 4.0.1 on SunOS4 reports this also when using X11R5, but not
    * with OpenWindow 3.0 (X11R4 based). */
 	(void) XrmDestroyDatabase(RDB);
+	if (!strcmp(mode, "run")) {
+		geometry = (char *) malloc(4);
+		(void) strcpy(geometry, "1x1");
+	}
 
 	/* Parse the rest of the command line */
 	for (argc--, argv++; argc > 0; argc--, argv++) {
@@ -2087,16 +2104,16 @@ extern void XlockrmParseCommand(
 void
 checkResources(void)
 {
-	extern char old_default_mode[];
+	extern char * old_default_mode;
 	int         i;
 
 	/* in case they have a 'xlock*mode: ' empty resource */
-	if (!mode || *mode == '\0')
+	if (!mode || !*mode)
 		mode = DEF_MODE;
 
-	if (!strcmp(old_default_mode, "")) {
-		(void) strncpy(old_default_mode, mode, 20);
-		old_default_mode[19] = '\0';
+	if (!old_default_mode || !*old_default_mode) {
+		 old_default_mode = (char *) malloc(strlen(mode) + 1);
+		(void) strcpy(old_default_mode, mode);
 	}
 	for (i = 0; i < numprocs; i++) {
 		if (!strcmp(LockProcs[i].cmdline_arg, mode)) {
